----
---- $Source: /var/cvs/nimbus/src/config/DeliverAuto/oracle/schema50_oracle.sql,v $
---- $Revision: 1.88.4.1 $
---- $Date: 2005/09/27 16:39:51 $
----
---- schema50.sql
----
---- Description: This is the Oracle schema definition for Nimbus (5.0).
----
---- Updated to v4.2 with schema41_42.sql (rev 1.26) dated 10/4/2004
---- Updated to v5.0 with schema42_50.sql (rev 1.5) dated 10/4/2004
---- Unable to make deviceExtendedAttributes, lockdownStatus, tasks and deviceCustomAttributes IOTables (index-organized)
---- Getting an erro of "no data segment to store overflow row-pieces"

ALTER SESSION SET nls_length_semantics=byte;

CREATE TABLE contextHelp (
        HelpKey varchar (255) NOT NULL ,
        HelpURL varchar (255) NOT NULL ,
        Description varchar (255) NULL
)
GO

CREATE TABLE DB_DeviceCpu (
        DeviceKey int NOT NULL ,
        CpuIndex int NOT NULL ,
        UpdateTime timestamp NOT NULL ,
        CpuName varchar (100)  ,
        CpuSpeed int  ,
        CONSTRAINT PK_DB_DeviceCpu_1__14 PRIMARY KEY
        (
                DeviceKey,
                CpuIndex
        )
) ORGANIZATION INDEX
GO

--- some columns such as nameFullDNS and name fields in following tables increased to 256 for HP UX

CREATE TABLE deviceNames (
        DeviceKey int NOT NULL ,
        nameSNMP varchar (60) DEFAULT (' ')CONSTRAINT DF_deviceName_nameSNMP_4__16 NULL ,
        nameIPX varchar (60) DEFAULT (' ') CONSTRAINT DF_deviceName_nameIPX_3__16 NULL ,
        nameDMI varchar (60) DEFAULT (' ') CONSTRAINT DF_deviceName_nameDMI_2__16 NULL ,
        nameFullDNS varchar (256) DEFAULT (' ') CONSTRAINT DF_deviceName_nameFullDNS_5 NULL ,
        nameActiveDisc varchar (60) DEFAULT (' ') CONSTRAINT DF_deviceName_nameActiveDisc_6 NULL ,
        CONSTRAINT PK___1__16 PRIMARY KEY
        (
                DeviceKey
        )
) ORGANIZATION INDEX
GO

-- PostgreSQL note - Change the data type of the timestamp field from
-- timestamp to smallint, since the timestamp datatype means something
-- completely different in MS SQL.
CREATE TABLE devices (
        DeviceKey int DEFAULT (0) CONSTRAINT DF_devices_DeviceKey_1__13 NOT NULL,
        Name varchar (256) DEFAULT (' ') CONSTRAINT DF_devices_Name_7__13 NOT NULL,
        GUID varchar(128) DEFAULT (' ') CONSTRAINT DF_devices_GUID_3__13 NULL,
        Discovered number(19)  DEFAULT (0) CONSTRAINT DF_devices_Discovered_2__13 NULL ,
        ProductSubType varchar(32) DEFAULT (' ') ,
        OverallStatus int DEFAULT (10) CONSTRAINT DF_devices_OverallStatus_1__20 NULL,
        ProductType int DEFAULT (0) CONSTRAINT DF_devices_ProductType_1__20 NULL,
        ProductTypeStr varchar(32) DEFAULT (' ') NULL,
        ProductName nvarchar2 (100) NULL ,
        timestamp number(19) DEFAULT (0) NOT NULL ,
        LockFlags int  DEFAULT (0) NULL,
        fullDNSName varchar(256),
        MxGUID  varchar(32),
        discoveredName nvarchar2(256) DEFAULT (' ') NULL,
        durableName nvarchar2(256) DEFAULT (' ') NULL,
        wwName nvarchar2(256) DEFAULT (' ') NULL,
        subType2 varchar(32) DEFAULT (' ') ,
        subType3 varchar(32) DEFAULT (' ') ,
        subType4 varchar(32) DEFAULT (' ') ,
        subType5 varchar(32) DEFAULT (' ') ,
        subType6 varchar(32) DEFAULT (' ') ,
        subType7 varchar(32) DEFAULT (' ') ,
        subType8 varchar(32) DEFAULT (' ') ,
        CONSTRAINT PK___5__11 PRIMARY KEY
        (
                DeviceKey
        )
) ORGANIZATION INDEX
GO

CREATE  INDEX dev_overallstat_index ON devices(OverallStatus )
GO


CREATE TABLE deviceProperties (
    DeviceKey int NOT NULL ,
    PropertyName varchar (64) NOT NULL ,
    propertyValue nvarchar2 (255) NULL,
    CONSTRAINT PK_deviceProperties PRIMARY KEY
    (
        DeviceKey,
        PropertyName
    )
) ORGANIZATION INDEX
GO


CREATE TABLE deviceSnmpSettings (
        DeviceKey int NOT NULL ,
        networkTimeout int NULL ,
        networkRetries int NULL ,
        icmpTimeout int NULL ,
        icmpRetries int NULL ,
        defaultProtoMask int DEFAULT(0) NULL,
        CONSTRAINT PK___2__19 PRIMARY KEY
        (
                DeviceKey
        )
) ORGANIZATION INDEX
GO

CREATE TABLE deviceStatusSources (
        StatusSourceName varchar (50) NOT NULL ,
        StatusSourceId int NOT NULL,
        StatusInterfaceClass varchar(128),
        PRIMARY KEY
        (
           StatusSourceName,
           StatusSourceId
        )
) ORGANIZATION INDEX
GO

CREATE TABLE DeviceStatusResults (
    NoticeId int NOT NULL ,
    PrevStatusValue int NULL ,
    StatusSourceId int NULL,
    CONSTRAINT PK_DeviceStatusResults PRIMARY KEY
    (
        NoticeId
    )
)
GO


CREATE TABLE deviceStatusValue (
    DeviceKey int NOT NULL ,
    StatusSourceId int NOT NULL ,
    StatusValue int NULL,
     PRIMARY KEY
    (
        DeviceKey,
        StatusSourceId
    )
) ORGANIZATION INDEX
GO


CREATE TABLE deviceUrls (
        DeviceKey int NOT NULL ,
        UrlName varchar (60) DEFAULT (' ') CONSTRAINT DF_deviceurls_UrlName_3__12 NOT NULL,
        Url varchar (255) DEFAULT (' ') CONSTRAINT DF_deviceurls_Url_2__12 NULL,
        UrlDescription nvarchar2 (255) DEFAULT (' ') CONSTRAINT DF_deviceUrls_UrlDescript7__10 NULL,
        CONSTRAINT PK_deviceurls_1__12 PRIMARY KEY
        (
                DeviceKey,
                UrlName
        )
) ORGANIZATION INDEX
GO

CREATE TABLE deviceUrlStrings (
        UrlName varchar (60) DEFAULT (' ') CONSTRAINT DF_deviceurls_UrlName_4__12 NOT NULL,
        UrlStringType varchar (70) DEFAULT (' ') CONSTRAINT DF_deviceurls_UrlStringTy6__12 NOT NULL,
        UrlStringKey varchar (255) DEFAULT (' ') CONSTRAINT DF_deviceurls_UrlStringKe5__12 NULL,
        CONSTRAINT PK___3__12 PRIMARY KEY
        (
                UrlName,
                UrlStringType
        )
) ORGANIZATION INDEX
GO

CREATE TABLE deviceUrlTypes (
        UrlName varchar (60) NOT NULL ,
        UrlType int NULL ,
        UserClass int NULL ,
        UrlInfo varchar (200) ,
        UrlBuilder varchar (100) NULL ,
        UrlStatusSource varchar (100),
        CONSTRAINT PK_deviceUrlTypes_12 PRIMARY KEY
        (
                UrlName
        )
) ORGANIZATION INDEX
GO

CREATE TABLE deviceExtendedAttributes (
    deviceKey int NOT NULL ,
    assetType varchar (255) DEFAULT (' ') NULL,
    assetClass varchar (255) DEFAULT (' ')  NULL,
    sysAdmin varchar (255) DEFAULT (' ') NULL,
    sysDepartment varchar (255) DEFAULT (' ')  NULL,
    sysSupplier varchar (255) DEFAULT (' ') NULL,
    warrantyText varchar (255) DEFAULT (' ') NULL,
    serviceDate varchar (255) DEFAULT (' ')  NULL,
    serviceContract varchar (255) DEFAULT (' ') NULL,
    serviceContact varchar (255) DEFAULT (' ')  NULL,
    purchasePrice varchar (64) DEFAULT (' ') NULL,
    purchaseDate varchar (64) DEFAULT (' ')  NULL,
    comments varchar (512) DEFAULT (' ') NULL,
    hwPollFailCount int DEFAULT (0) NULL,
    applications varchar (255) DEFAULT (' ') NULL,
    snoozeTimeMin int DEFAULT (0) NULL,
    snoozeStartTimeMs number(19) DEFAULT (0) NULL,
    CONSTRAINT PK_deviceExtendedAttributes PRIMARY KEY
    (
        deviceKey
    )
)
GO

insert into deviceExtendedAttributes select  deviceKey, ' ', ' ', ' ', ' ', ' ',' ', ' ', ' ', ' ', ' ', ' ',' ',0,' ',0,0 from devices
GO

---- hot_dialog_class_name no longer being used
CREATE TABLE filterCriteria (
        criteria_id int NOT NULL ,
        criteria_name varchar (255) NULL ,
        hot_dialog_class_name varchar (255) NULL ,
        criteria_data_object_name varchar (255) NULL ,
        criteria_type int NULL ,
        CONSTRAINT PK___4__10 PRIMARY KEY
        (
                criteria_id
        )
) ORGANIZATION INDEX
GO

CREATE TABLE filterInstanceDefinition (
        group_id int DEFAULT (0) CONSTRAINT DF_FilterInst_group_id_6__13 NOT NULL,
        view_id int DEFAULT (0) CONSTRAINT DF_FilterInst_view_id_8__13 NOT NULL,
        criteria_id int DEFAULT (0) CONSTRAINT DF_FilterInst_criteria_id4__13 NOT NULL,
        inclusion int DEFAULT (0) CONSTRAINT DF_FilterInst_inclusion_7__13 NOT NULL,
----        data_model nCLOB NULL ,
        data_model nvarchar2 (2000) NULL ,
        CONSTRAINT PKfid__3__13 PRIMARY KEY
        (
                group_id,
                view_id,
                criteria_id,
                inclusion
        )
)
GO


CREATE TABLE firstRunConfig (
        URLName varchar (255) NULL ,
        Title varchar (255) NULL ,
        Configured int NULL ,
        Variables varchar (255) NULL ,
        HelpURL varchar (255) NULL
)
GO


CREATE TABLE GC_TaskResults (
    DeviceKey int NOT NULL ,
    JobID varchar (128) NULL ,
    HmmoId varchar (32) NULL ,
    TimeStamp timestamp NOT NULL ,
    StatusStringId varchar (32) NULL ,
    Severity int NULL ,
    OtherText nvarchar2 (255) NULL
)
GO

CREATE  INDEX gc_taskresIndex ON GC_TaskResults(DeviceKey, JobId, HmmoId, TimeStamp)
GO



CREATE TABLE groups (
        GroupId int DEFAULT (0) CONSTRAINT DF_groups_GroupId_9__13 NOT NULL,
        Name nchar (70) DEFAULT (' ') CONSTRAINT DF_groups_Name_7__13 NOT NULL,
        Static smallint DEFAULT (1) CONSTRAINT DF_groups_Static_8__13 NULL,
        Description varchar (255) DEFAULT (' ') CONSTRAINT DF_groups_Description_5__13 NULL,
        Created timestamp DEFAULT (TO_TIMESTAMP('1999-12-31','YYYY-MM-DD')) CONSTRAINT DF_groups_Created_6__13 NOT NULL,
        LastModified timestamp DEFAULT (TO_TIMESTAMP('1999-12-31','YYYY-MM-DD')) CONSTRAINT DF_groups_LastModified_4__1 NOT NULL,
        GroupEstablished smallint DEFAULT (0) CONSTRAINT DF_groups_GroupEstablishe3__13 NULL,
        aclId int DEFAULT (0) CONSTRAINT DF_groups_aclId_1__13 NULL,
        creatorUserId int DEFAULT (0) CONSTRAINT DF_groups_creatorUserId_2__13 NULL,
        filterId int DEFAULT (0) CONSTRAINT DF_groups_filterId_1__13 NULL,
        CONSTRAINT PK_groups_1__12 PRIMARY KEY
        (
                GroupId
        )
) ORGANIZATION INDEX
GO

CREATE TABLE consolidatedNodeAuths (
        NodeID     varchar(32) NOT NULL,
        UserId     varchar(32) NOT NULL,
    PRIMARY KEY ( NodeID, UserId)
    )
GO

CREATE TABLE mibEnumXrefs (
        mib_id int NOT NULL ,
        enum_index int NOT NULL ,
        enum_value int NULL ,
        enum_text varchar (255) NULL ,
        severity_map int DEFAULT(0) NOT NULL ,
        CONSTRAINT PK___4__13 PRIMARY KEY
        (
                mib_id,
                enum_index
        )
) ORGANIZATION INDEX
GO

CREATE TABLE mibFiles (
        mib_file_id int NOT NULL ,
        mib_file varchar (64) NULL ,
        CONSTRAINT PK___9__14 PRIMARY KEY
        (
                mib_file_id
        )
) ORGANIZATION INDEX
GO

CREATE TABLE mibIndexes (
        mib_id int NOT NULL ,
        index_number int NOT NULL ,
        index_mib_id int NULL ,
        CONSTRAINT PK___2__13 PRIMARY KEY
        (
                mib_id,
                index_number
        )
) ORGANIZATION INDEX
GO

CREATE TABLE mibItems (
        mib_id int NOT NULL ,
        mib_name varchar (64) NOT NULL ,
        syntax_id int NULL ,
        syntax_range_flag int NULL ,
        mib_oid varchar (64) NULL ,
        oid_group int NULL ,
        oid_number int NULL ,
        access_id int NULL ,
        status_id int NULL ,
        enum_count int NULL ,
        instance_count int NULL ,
        mib_file_id int NULL ,
        CONSTRAINT mibItemsPK___1__13 PRIMARY KEY
        (
                mib_name
        )
) ORGANIZATION INDEX
GO

---- took MIB_OID, OIDValue and OIDRule out as keys because Oracle won't allow them to be
---- NULL and yet our code wants to put empty strings aka NULLs into it.
---- Had to take out sysObjectId from being the primary key because it wasn't unique enough.
CREATE TABLE stm_rules_snmp (
        sysObjectId varchar (150) NULL,
        priority int DEFAULT (1) NULL,
        sysOIDRule int DEFAULT (3) NULL,
        override_flag varchar (1) DEFAULT ('N') NULL,
        modified_by_user_flag varchar (1) DEFAULT ('N') NULL,
        productModel NVARCHAR2(128) DEFAULT (' ') NULL,
        productType int DEFAULT (0) NULL,
        productSubType int NULL,
        management_url VARCHAR (128) DEFAULT (' ') NULL,
        management_url_desc NVARCHAR2(128) DEFAULT (' ') NULL,
        MIB_OID VARCHAR (150) DEFAULT (' ') NULL,
        OIDDataType int DEFAULT (0) NULL,
        OIDValue VARCHAR (150) DEFAULT (' ') NULL,
        OIDRule int DEFAULT (0) NULL,
        OSName  VARCHAR (32) DEFAULT (' ') NULL,
        OSVendor VARCHAR (64) DEFAULT (' ') NULL,
        OSRevision VARCHAR (32) DEFAULT (' ') NULL
)
GO

CREATE INDEX snmp_rules_index ON stm_rules_snmp(sysObjectId)
GO

CREATE TABLE stm_rules_dmi (
        priority int DEFAULT (1) NULL,
        override_flag varchar (1) DEFAULT ('N') NULL,
        modified_by_user_flag varchar (1) DEFAULT ('N') NULL,
        productModel NVARCHAR2 (128) DEFAULT (' ') NULL,
        productType int DEFAULT (0) NULL,
        productSubType int NULL,
        management_url VARCHAR (128) DEFAULT (' ') NULL,
        management_url_desc NVARCHAR2(128) DEFAULT (' ') NULL,
        Comp1 VARCHAR (128) DEFAULT (' ') NULL,
        Group1 VARCHAR (128) DEFAULT (' ') NULL,
        SGroup1 VARCHAR (128) DEFAULT (' ') NULL,
        Attrib1 VARCHAR (128) DEFAULT (' ') NULL,
        Index1 VARCHAR (16) DEFAULT (' ') NULL,
        Val1 VARCHAR (128) DEFAULT (' ') NULL,
        Rule1 int DEFAULT (0) NULL,
        Comp2 VARCHAR (128) DEFAULT (' ') NULL,
        Group2 VARCHAR (128) DEFAULT (' ') NULL,
        SGroup2 VARCHAR (128) DEFAULT (' ') NULL,
        Attrib2 VARCHAR (128) DEFAULT (' ') NULL,
        Index2 VARCHAR (16) DEFAULT (' ') NULL,
        Val2 VARCHAR (128) DEFAULT (' ') NULL,
        Rule2 int DEFAULT (0) NULL,
        Comp3 VARCHAR (128) DEFAULT (' ') NULL,
        Group3 VARCHAR (128) DEFAULT (' ') NULL,
        SGroup3 VARCHAR (128) DEFAULT (' ') NULL,
        Attrib3 VARCHAR (128) DEFAULT (' ') NULL,
        Index3 VARCHAR (16) DEFAULT (' ') NULL,
        Val3 VARCHAR (128) DEFAULT (' ') NULL,
        Rule3 int DEFAULT (0) NULL,
        OSName  VARCHAR (32) DEFAULT (' ') NULL,
        OSVendor VARCHAR (64) DEFAULT (' ') NULL,
        OSRevision VARCHAR (32) DEFAULT (' ') NULL
)
GO




-- Oracle note -
-- Postgres data type for the timestamp fields were changed from timestamp (in MSSQL) to bigint.
-- For Oracle, need to use a number(19,0) since we don't have a bigint

CREATE TABLE notices (
        NoticeId int DEFAULT (0) CONSTRAINT DF_notices_NoticeId_2__13 NOT NULL,
        State int DEFAULT (0) CONSTRAINT DF_notices_State_5__13 NULL,
        NoticeType int DEFAULT (0) CONSTRAINT DF_notices_NoticeType_4__13 NULL,
        NoticeSeverity int DEFAULT (0) CONSTRAINT DF_notices_NoticeSeverity3__13 NULL,
        NoticePriority int DEFAULT (0) CONSTRAINT DF_notices_NoticePriority1__13 NULL,
        DeviceKey int DEFAULT (0) CONSTRAINT DF_notices_Device_1__13 NOT NULL,
        Generated    number(19) DEFAULT (0) CONSTRAINT DF_notices_Generated_1__13 NULL,
        Cleared      number(19) DEFAULT (0) CONSTRAINT DF_notices_Fixed_3__13 NULL,
        Completed    number(19) DEFAULT (0) CONSTRAINT DF_notices_Completed_2__13 NULL,
        LastChecked  number(19) DEFAULT (0) CONSTRAINT DF_notices_LastChecked_4__13 NULL,
        LastModified number(19) DEFAULT (0) CONSTRAINT DF_notices_LastModified_5__13 NULL,
        JobId	     VARCHAR(128) DEFAULT(' ') NULL,
        timestamp    number(19) DEFAULT (0) NOT NULL,
        AssignedTo   nvarchar2(255) NULL,
        Comments     nvarchar2(1000) NULL,
        CONSTRAINT PK_notices_1__13 PRIMARY KEY
        (
                NoticeId
        )
)
GO

CREATE INDEX SK_notices_Type ON notices(NoticeType)
GO
CREATE index notice_st_dev_sv_index on notices(State, deviceKey, noticeseverity)
GO

CREATE TABLE noticeType (
        GUID        varchar(32) NOT NULL,
        noticeType  int DEFAULT (0) NOT NULL,
        typeIdStr   varchar (255)  DEFAULT (0) NULL,
        category    varchar (100) NULL,
        dispHandler varchar (255) NULL ,
        rxHandler   varchar (255) NULL,
        defaultSeverity int DEFAULT (0) NULL,
        serviceEnable int DEFAULT (0) NULL,
        providerID    int DEFAULT (0) NULL,
        privilige     int DEFAULT (0) NULL,
        CONSTRAINT PK_noticetype_1__13 PRIMARY KEY
        (
                NoticeType
        )
)
GO

 CREATE  UNIQUE  INDEX noticeType_unique_key ON noticeType(typeIdStr)
GO


CREATE TABLE registeredMessages (
        MessageName varchar (255) NOT NULL ,
        MessageId int NOT NULL ,
        CONSTRAINT PK_registeredmessages_1__14 PRIMARY KEY
        (
                MessageId
        )
) ORGANIZATION INDEX
GO

CREATE TABLE ServiceNotices (
        NoticeID int NOT NULL ,
        ProviderID int NOT NULL ,
        ServiceID varchar (40) NULL ,
        SequenceNumber varchar (20) NULL,
        EventStatus int NULL ,
        EventURL varchar (256) NULL
)
GO

CREATE TABLE ServiceProvider (
        ProviderID int NOT NULL ,
        ProviderName varchar (256) NOT NULL ,
        ProviderURL varchar (256) NULL ,
        DefaultEventURL varchar (256) NULL
)
GO

---- several places are trying to insert a '' into the largevalue which is translating into a NULL.
---- Problem when largeValue was defined as NOT NULL
CREATE TABLE stringTableLarge (
        id int NOT NULL ,
        language varchar (2) NOT NULL ,
        largeValue nCLOB ,
        CONSTRAINT PK___7__17 PRIMARY KEY
        (
                id,
                language
        )
)
GO


CREATE TABLE swComponentEvents (
    noticeId int not null,
    deviceKey int not null,
    statusType int null,
    statusValue int null,
    logUrl	varchar(1024) null,
----    xmlContent BLOB null,
    xmlContent long raw null,
    updateTime timestamp null,
    jobId varchar (128) null)
GO


CREATE TABLE tableVersions (
        TableName varchar (255) NOT NULL ,
        TableVersion varchar (50) NOT NULL ,
        ContentsVersion varchar (50) NULL ,
        CONSTRAINT PK___11__13 PRIMARY KEY
        (
                TableName
        )
) ORGANIZATION INDEX
GO

CREATE TABLE timeFilter (
    Name nchar (255) NOT NULL ,
    Mon int NOT NULL ,
    Tue int NOT NULL ,
    Wed int NOT NULL ,
    Thu int NOT NULL ,
    Fri int NOT NULL ,
    Sat int NOT NULL ,
    Sun int NOT NULL ,
    IsDeletable smallint DEFAULT (1) NOT NULL
)
GO

CREATE TABLE trapAccessTypes (
        access_id int NOT NULL ,
        access_type varchar (50) NULL ,
        CONSTRAINT PK_accessTypes_1__13 PRIMARY KEY
        (
                access_id
        )
) ORGANIZATION INDEX
GO

CREATE TABLE trapData (
        rec_id int NOT NULL ,
        trap_id int NULL ,
        notice_id int NULL ,
        varbind_rec_count int NULL ,
----        origTrapInfo CLOB NULL ,
        origTrapInfo long NULL ,
        CONSTRAINT PK___6__14 PRIMARY KEY
        (
                rec_id
        )
)
GO

create index trap_data_nid_index on trapData (notice_id )
GO

CREATE TABLE trapItems (
        trap_id int NOT NULL ,
        trap_name varchar (64) NULL ,
        trap_enterprise varchar (64) NULL ,
        trap_generic_id int NULL ,
        trap_specific_id int NULL ,
        trap_severity_id int NULL ,
        trap_varbind_count int NULL ,
        cat_id int DEFAULT(0) NOT NULL ,
        sev_vb int DEFAULT(0) NOT NULL ,
        CONSTRAINT PK___8__13 PRIMARY KEY
        (
                trap_id
        )
) ORGANIZATION INDEX
GO
CREATE INDEX trap_rcv_lu_index on trapitems (trap_enterprise, trap_generic_id, trap_specific_id)
GO

CREATE TABLE trapCategoryTypes (
        cat_id int DEFAULT(0) NOT NULL,
        category_type varchar (64) NOT NULL ,
        CONSTRAINT PK___16__14 PRIMARY KEY
        (
                cat_id
        )
) ORGANIZATION INDEX
GO

CREATE TABLE trapSeverityTypes (
        severity_id int NOT NULL ,
        severity_type varchar (64) NULL ,
        CONSTRAINT PK___16__13 PRIMARY KEY
        (
                severity_id
        )
) ORGANIZATION INDEX
GO

CREATE TABLE trapStatusTypes (
        status_id int NOT NULL ,
        status_type varchar (64) NULL ,
        CONSTRAINT PK___5__13 PRIMARY KEY
        (
                status_id
        )
) ORGANIZATION INDEX
GO

CREATE TABLE trapSyntaxRanges (
        mib_id int NOT NULL ,
        hi_value int NOT NULL ,
        lo_value int NOT NULL ,
        CONSTRAINT PK___6__13 PRIMARY KEY
        (
                mib_id
        )
) ORGANIZATION INDEX
GO

CREATE TABLE trapSyntaxTypes (
        syntax_id int NOT NULL ,
        syntax_type varchar (64) NULL ,
        CONSTRAINT PK___7__13 PRIMARY KEY
        (
                syntax_id
        )
) ORGANIZATION INDEX
GO

CREATE TABLE trapVarbindData (
        trap_rec_id int NOT NULL ,
        varbind_number int NOT NULL ,
        varbind_oid varchar (255) NULL ,
        value_in_hex int NULL ,
        value varchar (255) NULL ,
        CONSTRAINT PK___8__14 PRIMARY KEY
        (
                trap_rec_id,
                varbind_number
        )
) ORGANIZATION INDEX
GO

CREATE TABLE trapVarbinds (
        trap_id int NOT NULL ,
        varbind_number int NOT NULL ,
        varbind_mib_id int NOT NULL ,
        CONSTRAINT PK___10__13 PRIMARY KEY
        (
                trap_id,
                varbind_number
        )
) ORGANIZATION INDEX
GO


CREATE TABLE viewCategories (
        Category nchar (255) DEFAULT (' ') CONSTRAINT DF_viewcatego_Category_3__10 NULL,
        isPublic smallint DEFAULT (0) CONSTRAINT DF_viewcatego_isPublic_4__10 NULL,
        creatorUserId int NULL,
        CONSTRAINT PK___2__10 PRIMARY KEY
        (
                Category
        )
) ORGANIZATION INDEX
GO


CREATE TABLE views (
        ViewId int NOT NULL ,
        ViewName nchar (70) DEFAULT (' ') CONSTRAINT DF_views_ViewName_2__15 NOT NULL,
        GroupId int DEFAULT (0) CONSTRAINT DF_views_GroupId_1__15 NULL,
        creatorUserId int DEFAULT (0) CONSTRAINT DF_views_creatorUserId_3__15 NULL,
        aclId int DEFAULT (0) CONSTRAINT DF_views_aclId_4__15 NULL,
        isPublic smallint DEFAULT (0) CONSTRAINT DF_views_isPublic_1__14 NULL,
        CONSTRAINT PK_views_1__15 PRIMARY KEY
        (
                ViewId
        )
) ORGANIZATION INDEX
GO

CREATE TABLE viewCategoriesTree (
        Location int NOT NULL ,
        ParentId nchar (255) DEFAULT (' ') CONSTRAINT DF_viewscateg_ParentId_4__10 NOT NULL,
        ChildId nchar (255) DEFAULT (' ') CONSTRAINT DF_viewscateg_ChildId_2__10 NOT NULL,
        IsView smallint DEFAULT (0) CONSTRAINT DF_viewscateg_IsView_3__10 NULL
)
GO

CREATE TABLE tableIndexes (
    indexKey varchar (120) NOT NULL ,
    indexValue int NOT NULL ,
    CONSTRAINT PK_tableIndexes_1__10 PRIMARY KEY
    (
        indexKey
    )
) ORGANIZATION INDEX
GO


CREATE TABLE clusterInfo
(
  ClusterDeviceKey    int       NOT NULL,
  ClusterType         int           NULL,
  ContactPerson       nchar(128)    NULL,
  ContactPhone        varchar(128)     NULL,
  ContactPager        varchar(128)     NULL,
  ContactEmail        varchar(128)     NULL,
  DialOutModem        varchar(128)     NULL,
  DialInModem         varchar(128)     NULL,
  ClusterLocation     nvarchar2(2000)  NULL,
  Applications        nvarchar2(2000)  NULL,
  Comments            nvarchar2(2000)  NULL,
  UpdateTime          number(19)  NULL,
  PRIMARY KEY (ClusterDeviceKey)
)
GO

CREATE TABLE clusterNodeInfo
(
  ClusterDeviceKey    int       NOT NULL,
  NodeDeviceKey       int       NOT NULL,
  ContactPerson       nchar(128)    NULL,
  ContactPhone        varchar(128)     NULL,
  ContactPager        varchar(128)     NULL,
  ContactEmail        varchar(128)     NULL,
  DialOutModem        varchar(128)     NULL,
  DialInModem         varchar(128)     NULL,
  Applications        nvarchar2(2000)  NULL,
  Comments            nvarchar2(2000)  NULL,
  UpdateTime          number(19)  	    NULL,
  PRIMARY KEY (ClusterDeviceKey, NodeDeviceKey)
)
GO


CREATE TABLE clusterType
(
  ClusterType         int        NOT NULL,
  ClusterDvUrlType    varchar(128)      NULL,
  ClusterProdId       varchar(128)      NULL,
  ClusterProdName     varchar(128)      NULL,
  ClusterVendor       varchar(128)      NULL,
  Description         varchar(255)      NULL,
  NodeDvUrlType       varchar(128)      NULL,
  PRIMARY KEY (ClusterType)
) ORGANIZATION INDEX
GO

CREATE TABLE clusterAlgorithm
(
  ClusterAlgorithmClassName      varchar(128)        NOT NULL,
  Sequence			 int		  NOT NULL,
  PRIMARY KEY (ClusterAlgorithmClassName)
) ORGANIZATION INDEX
GO

CREATE TABLE cmxType
(
  CMX_Type            int        NOT NULL,
  CMX_Name            varchar(128)  NOT NULL,
  Alias               varchar(128)  NULL,
  Description         varchar(255)  NULL,
  DeviceType          int        NULL,
  ClusterType         int        NULL,
  StatusProp          int        NULL,
  PropertyURL         varchar(128)      NULL,
  DataViewerURL       varchar(128)      NULL,
  AggregationURL      varchar(128)      NULL,
  DeviceSupportClass  varchar(128)      NULL,
  HasGlobalProperties int        NULL,
  HasNodalProperties  int        NULL,
  PRIMARY KEY (CMX_Type)
) ORGANIZATION INDEX
GO

CREATE TABLE clusterDeviceCmx
(
  DeviceKey          int         NOT NULL,
  CMX_TYPE           int         NOT NULL,
  PRIMARY KEY(DeviceKey,CMX_TYPE)
)
GO


CREATE TABLE cmEventText
(
  NoticeId       int          NOT NULL,
  TextIndex      int          NOT NULL,
  PropertyLabel  varchar(256) NULL,
  NumOfParams    int          NULL,
  Param1         varchar(256) NULL,
  Param2         varchar(256) NULL,
  Param3         varchar(256) NULL,
  Param4         varchar(256) NULL,
  Param5         varchar(256) NULL,
  PRIMARY KEY (NoticeId, TextIndex)
) ORGANIZATION INDEX
GO


--------------------------------------------------------------------------------
---- WBEM Relationship algorithms for cluster, complex (nPar), vPar
--------------------------------------------------------------------------------

CREATE TABLE WbemClusterAlgorithms
(
  WBEMAlgorithmClassName         varchar(128)        NOT NULL,
  Sequence			 int		  NOT NULL,
  PRIMARY KEY (WBEMAlgorithmClassName)
) ORGANIZATION INDEX
GO

CREATE TABLE WbemHPVirtualMachineAlgorithms
(
  WBEMAlgorithmClassName         varchar(128)        NOT NULL,
  Sequence			 int		  NOT NULL,
  PRIMARY KEY (WBEMAlgorithmClassName)
) ORGANIZATION INDEX
GO

CREATE TABLE WbemComplexAlgorithms
(
  WBEMAlgorithmClassName         varchar(128)        NOT NULL,
  Sequence			 int		  NOT NULL,
  PRIMARY KEY (WBEMAlgorithmClassName)
) ORGANIZATION INDEX
GO


--- Added Tables and Initial Data for Mib Manager

CREATE TABLE trapItemsEx
(
  trap_id       int NOT NULL,
  mib_file_id   int NULL,
  enabled_flag  CHAR(1) DEFAULT ('Y') NULL,
PRIMARY KEY ( trap_id )
) ORGANIZATION INDEX
GO



CREATE TABLE mibFilesEx
(
  mib_file_id   int NOT NULL,
  Module        varchar (60) NULL,
  flags         smallint NULL,
PRIMARY KEY ( mib_file_id )
) ORGANIZATION INDEX
GO


CREATE TABLE DC_CategoryChildren (
    ClassId int NOT NULL ,
    PollId int NOT NULL ,
    CONSTRAINT PK_DC_CategoryChildren_1__21 PRIMARY KEY
    (
        ClassId,
        PollId
    )
) ORGANIZATION INDEX
GO

CREATE TABLE DC_DMIVars (
    MifId int NOT NULL ,
    PrefMifName varchar (64) NULL ,
    DefiningBody varchar (64) NULL ,
    GroupName varchar (64) NULL ,
    SameGroupName varchar (64),
    Version varchar (8) NULL ,
    AttributeId int NULL ,
    AttributeStr varchar (64) NULL ,
    AttributeVal varchar (64),
    IndexInfo int NULL ,
    CONSTRAINT PK_DC_DMIVars_1__10 PRIMARY KEY
    (
        MifId
    )
) ORGANIZATION INDEX
GO

CREATE TABLE DC_DeviceDCState (
    DeviceKey int NOT NULL ,
    LastDCTimeStarted timestamp NULL ,
    LastDCTimeCompleted timestamp NULL ,
    LastHDCTimeStarted timestamp NULL ,
    DCFlags int NULL ,
    collectionState int NULL ,
    CONSTRAINT PK_DC_DeviceDCState_6__10 PRIMARY KEY
    (
        DeviceKey
    )
) ORGANIZATION INDEX
GO


CREATE TABLE DC_PolledData (
    PollId int NOT NULL ,
    Description varchar (80) NULL ,
    DataType int NULL ,
    PollOID varchar (80) NULL ,
    MIFFids varchar (16) NULL,
    IndexInfo int NULL ,
    HandlerClass varchar (128) NULL ,
    HandlerInfo varchar (128) NULL ,
    preferredProto int NULL ,
    historicalFlag smallint NULL ,
    keyData smallint NULL ,
    keyDataId int NULL ,
    CONSTRAINT PK_DC_PolledData_1__10 PRIMARY KEY
    (
        PollId
    )
) ORGANIZATION INDEX
GO

CREATE TABLE DC_PolledDataCategory (
    ClassId int NOT NULL ,
    ParentClassId int DEFAULT (0) CONSTRAINT DF_DC_polledD_ParentClass4__21 NULL,
    Name varchar (80) DEFAULT (' ') CONSTRAINT DF_DC_polledD_Name_3__21 NULL,
    HistoricalFlag smallint DEFAULT (0) CONSTRAINT DF_DC_polledD_HistoricalF2__21 NULL,
    hiddenFlag smallint DEFAULT (0) CONSTRAINT DF_DC_polledD_hiddenFlag_1__21 NULL,
    CONSTRAINT PK_DC_PolledDataCategory_5__21 PRIMARY KEY
    (
        ClassId
    )
) ORGANIZATION INDEX
GO


CREATE TABLE DC_Enclosure (
    Enclosure_LUID number(19) not null,
    NodeID number(19) not null,
    SnapshotID number(19) not null,
    Tag     nvarchar2 (256) null,
    dc_EnclosureMaxNumBladesX int null,
    dc_EnclosureMaxNumBladesY int null,
    dc_Address int null,
    dc_FuseCondition nvarchar2 (32)  null,
    dc_FusePresent nvarchar2 (32)  null,
    CONSTRAINT DC_Enclosure_PK PRIMARY KEY (Enclosure_LUID, NodeID, SnapshotID)
)
GO

CREATE TABLE swVersionWeights
(
keyFileName varchar(50),
divisionKey varchar(25),
osKey varchar(25),
version varchar(50),
weight int
)
GO

CREATE TABLE stringResource
(
    id int NOT NULL,
    subClass varchar(255) NOT NULL,
    resourceName varchar(64) NOT NULL,
    resourceClassName varchar(64) NOT NULL,
    CONSTRAINT PK___4__17 PRIMARY KEY
    (
        id
    )
) ORGANIZATION INDEX
GO

CREATE INDEX SK_stringresourceAll ON stringResource
(
    resourceName,
    subClass,
    resourceClassName
)
GO

CREATE TABLE noticeXMLData
(
noticeId int,
---- XMLData BLOB
XMLData long raw
)
GO

--- Prepopulated table to map the MIB OS value to the Unity OS value

CREATE TABLE mibOSToVCOS (
    mibOS varchar(30),
    cimOS varchar(10),
    packageOS varchar(10)
)
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('other (1)', '1', NULL)
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('netware (2)', '21', '32')
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('windowsnt (3)', '18', '7')
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('sco-unix (4)', '26', '13')
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('unixware (5)', '25', '25')
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('os-2 (6)', '12', '29')
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('ms-dos (7)', '14', '8')
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('dos-windows (8)', '15', '1')
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('windows95 (9)', '16', '3')
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('windows98 (10)', '17', '4')
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('open-vms (11)', '7', '54')
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('nsk (12)', '33', NULL)
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('windowsCE (13)', '19', NULL)
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('linux (14)', '36', '44')
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('windows2000 (15)', '58', '20')
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('tru64UNIX (16)', NULL, NULL)
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('windowsdotNet (17)', '69','69')
GO

insert into mibOSToVCOS
(mibOS
,cimOS
,packageOS)
Values('windowsdotNet-64-bit (18)', '70', '104')
GO



create view notices_view as
(
select  devices.Name as DeviceName, case when noticeSeverity=100 then 'Informational' when noticeSeverity = 1 then 'Normal' when noticeSeverity=2 then 'Warning' when noticeSeverity=3 then 'Minor' when noticeSeverity=4 then 'Major' when noticeSeverity=5 then 'Critical' else 'Unknown'  end as Severity,
                     case when state=1 then 'Discovered' when state=2 then 'Not Cleared' when state = 5 then 'Cleared' when state = 6 then 'IN Progress' end as state, generated, cleared, largeValue as Description from notices, noticeType, devices, stringresource, stringtablelarge where
                     notices.noticeType = noticeType.noticeType and
                     notices.deviceKey = devices.deviceKey and
                     stringresource.resourceclassname='Alerttype' and stringresource.subclass='description' and
                     noticeType.noticeType=stringresource.resourceName and
                     stringtablelarge.id = stringresource.id
)
GO


CREATE TABLE db_ThirdPartyLink (
    category nchar (255) NOT NULL ,
    linkName nchar (255) NOT NULL ,
    url nchar (255) NULL ,
    CONSTRAINT PK_db_ThirdPartyLink_1__13 PRIMARY KEY
    (
        linkName
    )
) ORGANIZATION INDEX
GO

CREATE TABLE securityNoticesData
(
    noticeId int NOT NULL,
    userName nchar(255) NULL,
    ipAddress nchar(20) NULL,
    deviceName nchar(255) NULL,
    CONSTRAINT PK_securityNoticesData PRIMARY KEY
    (
        noticeId
    )
) ORGANIZATION INDEX
GO


CREATE TABLE device_associations (
    DeviceKey1 int NOT NULL ,
    DeviceKey2 int NOT NULL ,
    AssociationTypeNumber char(80) NOT NULL,
    CONSTRAINT PK_device_associations PRIMARY KEY
    (
        AssociationTypeNumber,
        DeviceKey1,
        DeviceKey2
    )
) ORGANIZATION INDEX
GO

update device_associations
set associationtypenumber='MgmtProcToServer_Ilo' where associationtypenumber='1'
GO

update device_associations
set associationtypenumber='MgmtProcToServer_Rib' where associationtypenumber='10'
GO

update device_associations
set associationtypenumber='MgmtProcToServer_Ilo' where associationtypenumber='11'
GO

update device_associations
set associationtypenumber='MgmtProcToServer_Ia' where associationtypenumber='12'
GO

update device_associations
set associationtypenumber='MgmtProcToServer_Rcc' where associationtypenumber='13'
GO

update device_associations
set associationtypenumber='ServerToEnclosure' where associationtypenumber='2'
GO

update device_associations
set associationtypenumber='MgmtProcToEnclosure' where associationtypenumber='3'
GO

update device_associations
set associationtypenumber='EnclosureToRack' where associationtypenumber='4'
GO

update device_associations
set associationtypenumber='SwitchToEnclosure' where associationtypenumber='5'
GO

update device_associations
set associationtypenumber='NodeToCluster' where associationtypenumber='6'
GO

update device_associations
set associationtypenumber='MgmtProcToDesktop_Halo' where associationtypenumber='7'
GO

update device_associations
set associationtypenumber='DesktopToEnclosure' where associationtypenumber='8'
GO
CREATE TABLE noticeDetails (
    noticeId int NOT NULL ,
    jobNoticeId int NOT NULL ,
    timeStamp timestamp NOT NULL ,
    status int NULL ,
    resourceId varchar (64) NULL ,
    details varchar (256) NULL,
    CONSTRAINT PK_noticeDetails PRIMARY KEY
    (
        noticeId,
        jobNoticeId,
        timeStamp
    )
)
GO

CREATE TABLE associated_device_data
(
    deviceKey int NOT NULL,
    associatedDeviceKey int NOT NULL,
    associatedDeviceName varchar(255) NULL,
    associatedDeviceStatus int NULL,
    associatedDeviceType int NULL,
    AssociationTypeNumber char(80) NOT NULL,
    CONSTRAINT PK_associated_device_data PRIMARY KEY
    (
    deviceKey,
    associatedDeviceKey,
    AssociationTypeNumber
    )
)
GO


CREATE TABLE deviceDimensionInfo
(
    DeviceKey int NOT NULL,
    Slot int NULL,
    Height int NULL,
    Width int NULL,
    Depth int NULL,
    MaxNumItems int NULL,
    NumBladeSlotsUsed int NULL,
    SwitchesPresent int NULL,
    MaxNumItemsXDir int NULL,
    MaxNumItemsYDir int NULL,
    SlotsUsedXDir   int NULL,
    SlotsUsedYDir   int NULL,
    Source	    char(80) DEFAULT (' '),
    CONSTRAINT PK_deviceDimensionInfo PRIMARY KEY
    (
    DeviceKey
    )
)
GO

CREATE TABLE rackTopology
(
    Encl_DeviceKey int NOT NULL,
    Right_Neighbor_DeviceKey int NULL,
    Left_Neighbor_DeviceKey int NULL,
    CONSTRAINT PK_rackTopology PRIMARY KEY
    (
    Encl_DeviceKey
    )
)
GO

CREATE TABLE devContainerAndRole
(
    DeviceKey int NOT NULL ,
    EnclosureName varchar (255),
    RackName varchar (255),
    ContainerChain varchar (255),
    ServerRole nvarchar2(100),
    CONSTRAINT PK_devContainerAndRole PRIMARY KEY
    (
    DeviceKey
    )
)
GO


CREATE TABLE DB_DeviceInfo (
        DeviceKey int NOT NULL ,
        UpdateTime timestamp NOT NULL ,
        Description nvarchar2 (200) NULL ,
        Location nvarchar2 (200) NULL ,
        Contact nvarchar2 (200) NULL ,
        CONSTRAINT PK___1__17 PRIMARY KEY
        (
                DeviceKey
        )
) ORGANIZATION INDEX
GO

CREATE TABLE DB_DeviceInfoEx
(
        DeviceKey int NOT NULL ,
        UpdateTime timestamp NOT NULL ,
        TotalMemory numeric(18, 0) NULL ,
        ROMVersion nvarchar2 (80) NULL ,
        SerialNumber nvarchar2 (80) NULL ,
        AssetTag nvarchar2 (100) NULL ,
        OSName nvarchar2 (100) NULL ,
        OSType nvarchar2 (100) NULL ,
        OSVersion nvarchar2 (100) NULL ,
        ClusterName varchar (100) NULL ,
        OSDescription nvarchar2 (100) DEFAULT (' ') NULL,
        OSVendor nvarchar2 (64) NULL,
        TrustStatus int DEFAULT (0) NULL,
        ProductId nvarchar2(32),
        CONSTRAINT PK___2__17 PRIMARY KEY
        (
        DeviceKey
        )
) ORGANIZATION INDEX
GO


-- Report templates table
create table Reports
(
    rId	         int NOT NULL,
    rName        nvarchar2(255) NOT NULL,
----    ItemList	 CLOB NOT NULL,
    ItemList	 long NOT NULL,
    QName        varchar(255) NOT NULL,
    QId    	 int NOT NULL,
    ViewOption   int NOT NULL,
    CreatorID    int DEFAULT (-1),
    RunCount     int DEFAULT (0),
    EditFlag     int DEFAULT (1),
    Privilege	 int DEFAULT (1),
    PRIMARY KEY (rId)
)
GO

--Report Items table
create table ReportItems
(
    iId		   int NOT NULL,
    iName 	   varchar(255) NOT NULL,
    CatId          int NOT NULL,
    CatName        varchar(255) NOT NULL,
    DBViewName     nvarchar2(255) NOT NULL,
    DBViewColName  varchar(255) NOT NULL,
    Position       int NOT NULL,
    DispName       nvarchar2(255) NOT NULL,
    DispLocale     nvarchar2(255) NOT NULL,
    Privilege      int DEFAULT (0),
    PRIMARY KEY (iId)
)
GO

-- Report Categories table
create table ReportCategories
(
    cId		   int NOT NULL,
    cName 	   nvarchar2(255) NOT NULL,
    DBViewName	   nvarchar2(255) NOT NULL,
    DispName       nvarchar2(255) NOT NULL,
    DispLocale     nvarchar2(255) NOT NULL,
    DispFlag       int DEFAULT (1),
    DevFlag        int DEFAULT (1),
    superCId	   int DEFAULT(0),
    superCName 	   varchar(255) DEFAULT (' ') NULL,
    Privilege      int DEFAULT (0),
    PRIMARY KEY (cId)
)
GO

create view view_deviceAssociations as
(
select deviceKey as associatedDeviceKey,
       device_associations.deviceKey1 as DeviceKey ,
       RTRIM(name) as associatedDeviceName,
       overallstatus as associatedDeviceStatus,
       producttype as associatedDeviceType,
       AssociationTypeNumber as AssociationTypeNumber
from device_associations LEFT OUTER JOIN devices
ON  (device_associations.deviceKey2= devices.deviceKey )
)
GO

CREATE TABLE menuElements
(
    MenuId nchar(255) NOT NULL,
    Type int DEFAULT (0) CONSTRAINT DF_menuelemen_Type_2__13 NOT NULL,
    UserClass int DEFAULT (0) CONSTRAINT DF_menuelemen_UserClass_3__13 NOT NULL,
    aclId int DEFAULT (0) CONSTRAINT DF_menuelemen_aclId_1__13 NOT NULL,
    viewId int DEFAULT (-1) CONSTRAINT DF_menuElements_viewId NOT NULL,
    userId int DEFAULT (-1) CONSTRAINT DF_menuElements_userId NOT NULL,
    viewPollingRate int DEFAULT (5) CONSTRAINT DF_menuElements_viewPolling NOT NULL,
    showStatus int DEFAULT (1) CONSTRAINT DF_menuElements_showStatus NOT NULL,
    CONSTRAINT PK_menuelements_1__13 PRIMARY KEY
    (
    MenuId
    )
) ORGANIZATION INDEX
GO
CREATE TABLE menuTree
(
    Location int NOT NULL,
    Parent nchar(255) NOT NULL,
    Child nchar(255) NOT NULL,
    CONSTRAINT PKmtree__13__13 PRIMARY KEY
    (
    Location
    )
) ORGANIZATION INDEX
GO

--
-- Create 3.1 table for Folder support
--
CREATE TABLE FolderQueryStatusPolicy (
    type int NOT NULL ,
    className varchar(128) NOT NULL,
    PRIMARY KEY (type)
) ORGANIZATION INDEX
GO

INSERT into FolderQueryStatusPolicy
(type,
 className)
Values (1,'com.hp.mx.core.foldermanager.QueryStatusBySeverityPolicy')
GO

INSERT into FolderQueryStatusPolicy
(type,
 className)
Values (2,'com.hp.mx.core.foldermanager.QueryStatusByEventSeverityPolicy')
GO

INSERT into FolderQueryStatusPolicy
(type,
 className)
Values (3,'com.hp.mx.core.foldermanager.QueryStatusByClusterSeverityPolicy')
GO


--
-- Modify 3.1 Device License Table
--

CREATE TABLE deviceLicenseInfo
(
    deviceKey          int NOT NULL,
    licKey             varchar (255) NOT NULL,
    numberLicPurchased varchar(32) DEFAULT (0),
    numberLicUsed      varchar(32) DEFAULT (0),
    keyVer             varchar (80) NULL,
    productName        varchar (255) NULL,
    productVer         varchar (255) NULL,
    licType            varchar (80) NULL,
    licDate	       varchar (80) NULL,
    expirationDate     varchar (80) NULL,
    collectDate        timestamp NULL,
    licStatus          varchar(255) NOT NULL,
    licSRC             varchar(10) NOT NULL,
    CONSTRAINT PK_deviceLicenseInfo PRIMARY KEY
    (
        deviceKey,
        licKey
    )
)
GO

CREATE TABLE LicenseReportingAlgorithms (
    AlgorithmName varchar(255) NOT NULL,
    PRIMARY KEY (AlgorithmName)
) ORGANIZATION INDEX
GO

--
-- Create Views to support device license reporting
--


CREATE VIEW licenseCounts
AS
 SELECT deviceLicenseInfo.licKey, count(deviceLicenseInfo.licKey) as curCount from deviceLicenseInfo group by licKey
GO


CREATE VIEW R_deviceLicenseInfo
AS (
SELECT deviceLicenseInfo.deviceKey, deviceLicenseInfo.numberLicPurchased, deviceLicenseInfo.numberLicUsed, deviceLicenseInfo.keyVer,
       deviceLicenseInfo.licKey, deviceLicenseInfo.licType, deviceLicenseInfo.licDate,
       deviceLicenseInfo.productName, deviceLicenseInfo.productVer, deviceLicenseInfo.expirationDate,
       deviceLicenseInfo.collectDate, devices.Name AS DeviceName, licenseCounts.curCount,
       deviceLicenseInfo.licStatus, - 1 AS SnapShotID
FROM deviceLicenseInfo, devices, licenseCounts where
    deviceLicenseInfo.deviceKey = devices.DeviceKey and
    deviceLicenseInfo.licKey = licenseCounts.licKey
)
GO


--
-- Tables for VPM
--
CREATE TABLE lockdownStatus (
    deviceKey int NOT NULL ,
    ldStatus int NULL ,
    deviceName char(255) Default (' ') NOT NULL,
    NextScanName char(255) Default (' ') NOT NULL,
    NextScanDate char(255) Default (' ') NOT NULL,
    NextVulChk char(255) Default (' ') NOT NULL,
    LastScanName char(255) Default (' ') NOT NULL,
    LastScanDate char(255) Default (' ') NOT NULL,
    LastVulChk char(255) Default (' ') NOT NULL,
    Critical char(255) Default (' ') NOT NULL,
    Major char(255) Default (' ') NOT NULL,
    Minor char(255) Default (' ') NOT NULL,
    executive char(255) Default (' ') NOT NULL,
    detailed char(255) Default (' ') NOT NULL,
    simple char(255) Default (' ') NOT NULL,
    summary char(255) Default (' ') NOT NULL,
    ports char(255) Default (' ') NOT NULL,
    LPatchDate char(255) Default (' ') NOT NULL,
    LPatchApplied char(255) Default (' ') NOT NULL,
    PatchRqd char(255) Default (' ') NOT NULL,
    PatchMiss char(255) Default (' ') NOT NULL,
    Warning char(255) Default (' ') NOT NULL,
    CONSTRAINT PK_lockdown PRIMARY KEY
    (
        deviceKey
    )
)
GO

CREATE TABLE ppaStatus (
    deviceKey int NOT NULL ,
    perfStatus int NULL,
    CONSTRAINT PK_ppaStatus PRIMARY KEY
    (
        deviceKey
    )
) ORGANIZATION INDEX
GO


--
-- Upgrade info to go from 3.2 schema to 4.0 (nimbus)
--



CREATE TABLE deviceMxObjValues (
    deviceKey int NOT NULL ,
    createdBy varchar (128) ,
    createdTime number(19) NULL ,
    modifiedBy varchar (128) ,
    modifiedTime number(19) NULL,
    CONSTRAINT PK_deviceMxObjValues PRIMARY KEY
    (
        deviceKey
    )
)
GO


-- the Gryphon tables...
create table hpmxSchemaVersion
(
    schemaVersion int PRIMARY KEY,
    SIMVersion   nvarchar2(32) DEFAULT(' ') NOT NULL
)
GO

create table hpmxObject
(
    LUID          number(19) PRIMARY KEY,
    GUID          varchar(32) NOT NULL,
    CreatedBy     varchar(128) NULL,
    CreatedTime   number(19) NULL,
    ModifiedBy    varchar(128) NULL,
    ModifiedTime  number(19) NULL,
    ClassType     varchar(128) NULL
)
GO

create table hpmxAuthorization
(
    LUID          number(19) PRIMARY KEY,
    UserID        varchar(32) NOT NULL,
    ToolBoxID     varchar(32) NOT NULL
)
GO

create table hpmxNodeAuthorization
(
    LUID          number(19) PRIMARY KEY,
    NodeID        varchar(32) NOT NULL
)
GO

create table  hpmxNodeGroupAuthorization
(
    LUID          number(19) PRIMARY KEY,
    NodeGroupID   varchar(32) NOT NULL,
    NodeGroupLUID number(19) NOT NULL
)
GO


create table hpmxNodeGroup
(
    LUID          number(19) PRIMARY KEY,
    PersistedName varchar(80) NULL,
    AssocCollLUID number(19)
)
GO

create table hpmxGroup
(
    LUID                 number(19) PRIMARY KEY,
    PersistedDescription nvarchar2(255) NULL,
    SpecificationManner  int NULL,
    AdditionalData       varchar(255) NULL
)
GO

create table hpmxNodeGroupObjects
(
    NodeGroupLUID   number(19) NOT NULL,
    NodeID          varchar(32) NOT NULL,
    PRIMARY KEY(NodeGroupLUID, NodeID)
)
GO

create table hpmxToolBox
(
    LUID                  number(19) PRIMARY KEY,
    PersistedName         nvarchar2(16) NULL,
    PersistedDescription  nvarchar2(255) NULL,
    IsEnabled             smallint NULL
)
GO

create table hpmxSubject
(
    LUID                 number(19) PRIMARY KEY,
    PersistedDescription nvarchar2(255) NULL,
    PrivilegeCode        int NULL
)
GO

create table hpmxUser
(
    LUID            number(19) PRIMARY KEY,
    PersistedName   nvarchar2(128) NULL,
    FullName        nvarchar2(128) NULL,
    TelephoneNumber varchar(80) NULL,
    EmailAddress    nvarchar2(80) NULL,
----    IPLoginInclusionRanges CLOB NULL,
----    IPLoginExclusionRanges CLOB NULL,
    IPLoginInclusionRanges varchar(4000) NULL,
    IPLoginExclusionRanges varchar(4000) NULL,
    Hidden          smallint NULL,
    GroupBased      smallint NULL
)
GO

create table hpmxUserAssignedUserGroups
(
    UserLUID        number(19) NOT NULL,
    UserGroupID     varchar(32) NOT NULL,
    PRIMARY KEY(UserLUID, UserGroupID)
)
GO

create table hpmxUserGroup
(
    LUID            number(19) PRIMARY KEY,
    PersistedName   nvarchar2(128) NULL,
    FullName        nvarchar2(128) NULL,
----    IPLoginInclusionRanges CLOB NULL,
----    IPLoginExclusionRanges CLOB NULL,
    IPLoginInclusionRanges varchar(4000) NULL,
    IPLoginExclusionRanges varchar(4000) NULL
)
GO

create table hpmxPagerInfo
(
    UserLUID      number(19) PRIMARY KEY,
    PhoneNumber   varchar(100) NOT NULL,
    PinNumber     varchar(100) NULL,
    MsgLength     varchar(32) NULL,
    BaudRate      varchar(32) NULL,
    DataBit       varchar(32) NULL,
    ParityBit     varchar(32) NULL,
    StopBit       varchar(32) NULL
)
GO

create table hpmxTool
(
    LUID             number(19) PRIMARY KEY,
    Name             nvarchar2(255) NULL,
    OwnedByID        varchar(32) NULL,
----    Description      CLOB NULL,
----    Comment_         CLOB NULL,
    Description      varchar(4000) NULL,
    Comment_         varchar(4000) NULL,
    ExecutedBy       varchar(32) NULL,
    DisplayHandler   varchar(128) NULL,
    ToolGroup        varchar(80) NULL,
    Revision         varchar(20) NULL,
    ToolBoxEnabled   smallint NULL,
    DefaultTarget    varchar(80) NULL,
    ToolType         varchar(32) NULL,
    MaxTargets       int NULL,
    Visible          smallint NULL,
    JobLogEnabled    smallint NULL,
    Schedulable      smallint NULL,
    AcceptsTargets   smallint NULL
)
GO

create table hpmxAutomationTool
(
    LUID number(19) PRIMARY KEY,
----    MessageID CLOB NULL
    MessageID varchar (255) NULL
)
GO

create table hpmxAppLaunchTool
(
    LUID number(19)  PRIMARY KEY,
----    AppParameters CLOB NULL,
    AppParameters varchar(4000) NULL,
    AlertDriven   smallint NULL
)
GO

create table hpmxWebLaunchTool
(
    LUID           number(19) PRIMARY KEY,
    MainURL        varchar(255) NULL,
    SmallURL       varchar(255) NULL,
    CurrentURL     varchar(255) NULL,
    StatusURL      varchar(255) NULL,
----    TargetFormat   CLOB NULL
    TargetFormat   varchar(4000) NULL
)
GO

create table hpmxCommandTool
(
    LUID            number(19) PRIMARY KEY,
----    CommandLine     CLOB NULL,
    CommandLine     varchar(4000) NULL,
    ExecutedShell   varchar(32) NULL,
    SaveOutputToLog smallint NULL,
    CommandType     varchar(32) NULL,
----    EnvVarsArray    CLOB NULL
    EnvVarsArray    varchar(4000) NULL
)
GO

create table hpmxSSACommandTool
(
    LUID number(19) PRIMARY KEY
)
GO

create table hpmxMSACommandTool
(
    LUID             number(19) PRIMARY KEY,
    MsaManagerNode   varchar(32) NULL
)
GO

create table hpmxParameter
(
    ToolLUID      number(19) NOT NULL,
    Name          nvarchar2(32) NULL,
    hpmxIndex     int NOT NULL,
    Prefix        nvarchar2(80) NULL,
    Prompt        nvarchar2(80) NULL,
    Required      smallint NULL,
    Private       smallint NULL,
    PRIMARY KEY ( ToolLUID, hpmxIndex)
)
GO

create table hpmxNameValueOperator
(
    ToolLUID      number(19) NOT NULL,
    Name          varchar(32) NULL,
    OperatorValue int NULL,
    FilterTypeValue int NOT NULL,
    Value         nvarchar2(80) NULL,
    OrIndex       int NOT NULL,
    AndIndex      int NOT NULL,
    PRIMARY KEY ( ToolLUID, OrIndex, AndIndex, FilterTypeValue)
)
GO

create table hpmxFileCopyPair
(
    ToolLUID        number(19) NOT NULL,
    Name            varchar(32) NULL,
    SourcePath      varchar(128) NOT NULL,
    DestinationPath varchar(128) NOT NULL,
    hpmxIndex       int NULL,
    PRIMARY KEY(ToolLUID, SourcePath, DestinationPath)
)
GO

create table hpmxClientAttributes
(
    ObjectLUID      number(19) NOT NULL,
    Name            varchar(128) NOT NULL,
----    Value           CLOB NULL,
    Value           varchar(4000) NULL,
    hpmxIndex       int NULL,
    PRIMARY KEY(ObjectLUID, Name)
)
GO

create table hpmxEnvironmentVariable
(
    ObjectLUID      number(19) NOT NULL,
    Name            varchar(30) NOT NULL,
----    Value           CLOB NULL,
    Value           varchar(4000) NULL,
    hpmxIndex       int NULL,
    PRIMARY KEY(ObjectLUID, Name)
)
GO

create table hpmxToolAssignedToolBoxes
(
    ToolLUID     number(19) NOT NULL,
    ToolBoxID    varchar(32) NOT NULL,
    PRIMARY KEY(ToolLUID, ToolBoxID)
)
GO

create table hpmxJob
(
    JobID             varchar(267),
    TaskID            varchar(32),
    ExecuteAsUser     varchar(128) NULL,
    TaskRunBy         varchar(128) NULL,
    ToolName          varchar(255) NULL,
    ToolType          varchar(32) NULL,
    StateValue        int NULL,
    RunNow            smallint NULL,
    StartTime         number(19) NULL,
    EndTime           number(19) NULL,
----    ExceptionText     CLOB NULL,
----    ExceptionClass    CLOB NULL,
    ExceptionText     varchar(4000) NULL,
    ExceptionClass    varchar(4000) NULL,
    TargetCount       int NULL,
----    CommandLine       CLOB NULL,
----    FileCopySources   CLOB NULL,
----    FileCopyDestinations CLOB NULL,
    CommandLine       varchar(4000) NULL,
    FileCopySources   varchar(4000) NULL,
    FileCopyDestinations varchar(4000) NULL,
    PRIMARY KEY(JobID)
)
GO

create table hpmxTargetStatus
(
    JobID             varchar(267),
    Hostname          varchar(256),
    NodeID            varchar(32),
    FileCount         int NULL,
    StateValue        smallint NULL,
    ExitCode          int NULL,
    BlockCount        int NULL,
----    ExceptionText     CLOB NULL,
----    ExceptionClass    CLOB NULL,
    ExceptionText     varchar(4000) NULL,
    ExceptionClass    varchar(4000) NULL,
    PRIMARY KEY(JobID, HostName)
)
GO


--
-- Remove the timestamp column for IPAddress table
--
CREATE TABLE IPAddress (
    DeviceKey       int DEFAULT (0) CONSTRAINT DF_IPAddress_DeviceKey_4__15 NOT NULL,
    ipindex         int DEFAULT (0) CONSTRAINT DF__IPAddress__ipind__7350E786 NOT NULL,
    IPAddress       varchar (16) DEFAULT (' ') CONSTRAINT DF_IPAddress_IPAddress_5__15 NOT NULL,
    IPAddressNumber number(19) DEFAULT (0) CONSTRAINT DF_IPAddress_IPAddressNum6__15 NOT NULL,
    MACaddr         varchar (12) DEFAULT (' ') NOT NULL,
    IPsubnetMask    varchar (16) DEFAULT (' ') NOT NULL,
    IFType          varchar (8) DEFAULT (' ') NOT NULL,
    CONSTRAINT PK___3__15 PRIMARY KEY
    (
        DeviceKey,
        ipindex,
        IPAddress
    )
) ORGANIZATION INDEX
GO



--
-- Remove the timestamp column for IPXAddress table
--
CREATE TABLE IPXAddress (
    DeviceKey  int NOT NULL ,
    IPXAddress varchar (25) DEFAULT (' ') CONSTRAINT DF_IPXAddress_IPXAddress_3__16 NOT NULL,
    ipxIndex   int NOT NULL,
    CONSTRAINT PK_IPXAddress_2__16 PRIMARY KEY
    (
        DeviceKey,
        IPXAddress,
        ipxIndex
    )
) ORGANIZATION INDEX
GO



-- create new table for task data
CREATE TABLE tasks (
    GUID varchar(32) NULL,
    TaskKey int NOT NULL ,
    ToolKey int NOT NULL ,
    Configuration nCLOB NULL ,
    Name nchar (70) NULL ,
    createdByUser nvarchar2(128) NULL ,
    modifiedByUser nvarchar2(128) NULL ,
    ownedByUser nvarchar2(128) NULL ,
    createTime number(19) NOT NULL ,
    lastEditTime number(19) NOT NULL ,
    queryId int NULL ,
    groupLUID number(19) NULL ,
    lastExecutedTime number(19) NULL ,
    runCount int NULL ,
    sysDefined smallint NULL,
    secureDataKeys nCLOB NULL,
    languageStr nchar(64) NULL,
    CONSTRAINT PK_tasks__2__15 PRIMARY KEY
    (
        TaskKey
    )
---- ) ORGANIZATION INDEX
)
GO

CREATE TABLE  taskSchedule (
    TaskId int NOT NULL ,
    IntervalType int NOT NULL ,
    IntervalPeriod int NOT NULL ,
    ExecutionDay int NOT NULL ,
    ExecutionTime number(19) NOT NULL ,
    BaseExecutionTime number(19) NOT NULL ,
    ScheduleType int NOT NULL ,
    TimeFilterName nchar (255)  NULL ,
    TimeFilterEnabled int NOT NULL ,
    TimeFilterChecked int NOT NULL ,
    RunOnStartup int NOT NULL ,
    HasRunFlag int NOT NULL ,
    MaxRunCount int NOT NULL ,
    RunUntilTime number(19) NOT NULL ,
    DisabledFlag int NULL
)
GO

CREATE TABLE  taskQueryContents (
    NoticeId int NOT NULL ,
    DeviceKey int NOT NULL ,
    TaskId int NOT NULL ,
    OldFlag int NOT NULL
)
GO

CREATE TABLE nodeSubTypesEnum (
    enumOrd int NULL ,
    enumLabel varchar (64) NULL
)
GO

CREATE TABLE nodeTypesEnum (
    enumOrd int NULL ,
    enumLabel varchar (64) NULL
)
GO

CREATE TABLE deviceProtocolInfo
(
    DeviceKey      int DEFAULT (0) NOT NULL,
    IPAddressable  int  DEFAULT (0) NOT NULL,
    IPXAddressable int  DEFAULT (0) NOT NULL,
    SNMP           int DEFAULT (0) NOT NULL,
    SNMPverStr     nvarchar2(32) DEFAULT (' ') NULL,
    HTTP           int  DEFAULT (0) NOT NULL,
    DMI            int  DEFAULT (0) NOT NULL ,
    DMIverStr      nvarchar2(32) DEFAULT (' ') NULL,
    WBEM           int  DEFAULT (0) NOT NULL,
    WBEMverStr     nvarchar2(32) DEFAULT (' ') NULL,
    SSH            int DEFAULT (0) NOT NULL ,
    SSHverStr      nvarchar2(64) DEFAULT (' ') NULL,
    SMH            int DEFAULT (0) NOT NULL ,
    SMHverStr      nvarchar2(32) DEFAULT (' ') NULL,
    PrimaryAddress nvarchar2(32)  DEFAULT (' ') NULL,
    WMIProxyID     number(19) DEFAULT (0) NOT NULL,
    CONSTRAINT PK_devProto__2__15 PRIMARY KEY
    (
        DeviceKey
    )
) ORGANIZATION INDEX
GO

CREATE TABLE hpmxAutomationTaskResults
(
    jobID       varchar(128),
    noticeID    int,
    subTypeID   int,
    systemName  varchar(255),
    timeStamp   TIMESTAMP,
    exitCode    int,
    status      int,
    resourceID  VARCHAR(64),
    details     NVARCHAR2(512),
    CONSTRAINT PK_hpmxAutomationTaskResults PRIMARY KEY
    (
        jobID, noticeID, subTypeID
    )
)
GO

CREATE TABLE WMIProxy (
        LUID number(19) NOT NULL PRIMARY KEY,
        Name varchar(255) NOT NULL,
        WmiProxyIP varchar(32) DEFAULT (' ') NOT NULL,
        Port int DEFAULT (5989) NOT NULL,
        Modify_ int DEFAULT (0) NOT NULL
)
GO

create view deviceTypesEnum as
(
    select largevalue as displayString, resourceName as enumStr from stringTableLarge
        Join  stringresource on stringtablelarge.id=stringresource.id and stringresource.resourceClassName='NodeTypesEnum'
        and stringresource.subclass='dynamicMap'
)
GO

create view deviceSubTypesEnum as
(
    select largevalue as displayString, resourceName as enumId from stringTableLarge
        Join  stringresource on stringtablelarge.id=stringresource.id and stringresource.resourceClassName='NodeSubTypesEnum'
        and stringresource.subclass='dynamicOrdMap'
)
GO
create view alertTypesEnum as
(
    select largevalue as displayString, resourceName as enumId from stringTableLarge
        Join  stringresource on stringtablelarge.id=stringresource.id and stringresource.resourceClassName='AlertType'
        and stringresource.subclass='label'
)
GO
create view alertTypesDescrEnum as
(
    select largevalue as displayString, resourceName as enumId from stringTableLarge
        Join  stringresource on stringtablelarge.id=stringresource.id and stringresource.resourceClassName='AlertType'
        and stringresource.subclass='description'
)
GO

CREATE TABLE LMCertificateList (
        deviceKey int DEFAULT (0) NOT NULL,
        deviceType varchar (255) DEFAULT (' ') NULL,
        deviceIP varchar (255) DEFAULT (' ') NULL,
        deviceSN varchar (255) DEFAULT (' ') NULL,
        nodeName  varchar (255) DEFAULT (' ') NULL,
        licenseKey varchar (36) DEFAULT (' ') NULL,
        licenseKeyVer varchar (36) DEFAULT (' ') NULL,
        licenseType varchar (255)  DEFAULT (' ') NULL,
        licenseTypeCode varchar (30) DEFAULT (' ')  NULL,
        certificateDate varchar (30) DEFAULT (' ') NULL,
        certificateVersion varchar (30) DEFAULT (' ') NULL,
        certificateSN varchar (30) DEFAULT (' ') NULL,
        productCode varchar (30) DEFAULT (' ')  NULL,
        productVcode varchar (30) DEFAULT (' ') NULL,
        productName varchar (255) DEFAULT (' ')  NULL,
        productVersion varchar (255) DEFAULT (' ') NULL ,
        seatsMax varchar (15) DEFAULT (' ') NULL,
        seatsUsed varchar (15) DEFAULT (' ') NULL,
        daysMax varchar (15) DEFAULT (' ') NULL,
        daysUsed varchar (15) DEFAULT (' ') NULL,
        status varchar (255) DEFAULT (' ') NULL,
        collectdate varchar (30) DEFAULT (' ') NULL,
        source int DEFAULT (0) NOT NULL
)
GO

CREATE TABLE LMProductNameList (
        nameIndex int NOT NULL,
        productName varchar (255) DEFAULT (' ') NULL,
        keyDispose int DEFAULT (0) NOT NULL
)
GO

CREATE TABLE LMLicenseTypeList (
        lictypIndex int NOT NULL,
        licenseType varchar (60) DEFAULT (' ') NULL
)
GO

CREATE TABLE collections (
    LUID  number(19) NOT NULL,
    Name varchar (80),
    DefaultView varchar (256),
    IsHidden smallint NULL,
    EditFlags int NULL,
    Type int DEFAULT (1) NOT NULL,
    CONSTRAINT PK_collections PRIMARY KEY (LUID)
)
GO

CREATE TABLE collectionMembers (
    CollectionLUID number(19) NOT NULL,
    MemberObjectID varchar (32) NOT NULL,
    ObjectType varchar (32),
    Position int NOT NULL,
    IsHidden smallint NULL,
    DisplayStatusFlag smallint NULL,
    EditFlags int NULL,
    DefaultView varchar (64),
    CONSTRAINT PK_collectionMembers PRIMARY KEY
    (
        CollectionLUID, MemberObjectID
    )
)
GO

CREATE TABLE deviceCustomAttributes (
    deviceKey int NOT NULL ,
    custField1 varchar (255) NULL ,
    custField2 varchar (255) NULL ,
    custField3 varchar (255) NULL ,
    custField4 varchar (255) NULL ,
    custField5 varchar (255) NULL ,
    custField6 varchar (255) NULL ,
    custField7 varchar (255) NULL ,
    custField8 varchar (255) NULL ,
    custField9 varchar (255) NULL ,
    custField10 varchar (255) NULL ,
    custField11 varchar (255) NULL ,
    custField12 varchar (255) NULL ,
    custField13 varchar (255) NULL ,
    custField14 varchar (255) NULL ,
    custField15 varchar (255) NULL ,
    custField16 varchar (255) NULL ,
    custField17 varchar (255) NULL ,
    custField18 varchar (255) NULL ,
    custField19 varchar (255) NULL ,
    custField20 varchar (255) NULL,
    CONSTRAINT PK_deviceCustomAttributes PRIMARY KEY
    (
        deviceKey
    )
)
GO

CREATE TABLE devCustAttributeMap (
    internalAttributeId char (16) NOT NULL ,
    pluginAttributeId varchar (128) NOT NULL
)
GO

---
--- DATA COLLECTION TABLES
---



-- Table:  CIM_Chassis
CREATE TABLE  CIM_Chassis  (
   Chassis_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   CreationClassName  nvarchar2(256) NULL,
   ElementName nvarchar2(255),
   Manufacturer nvarchar2(256),
   Tag  nvarchar2(256) NULL,
   dc_SystemCreationClassName  nvarchar2(256) ,
   dc_SystemName  nvarchar2(256)  ,
   Name  nvarchar2(256),
   Width  number,
   Height  number,
   Depth  number,
   SerialNumber  nvarchar2(64),
   PartNumber  nvarchar2(256),
   SKU  nvarchar2(64),
   Model  nvarchar2(64),
   ChassisTypes  smallint,
   TypeDescriptions  nvarchar2(512),
   Version  nvarchar2(64),
   OtherIdentifyingInfo  nvarchar2(512),
   R_Model nvarchar2(256),
   dc_ProductId nvarchar2 (256),
  CONSTRAINT  CIM_Chassis_pkey  PRIMARY KEY ( Chassis_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  CIM_ComputerSystem
CREATE TABLE  CIM_ComputerSystem  (
   ComputerSystem_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   Name  nvarchar2(256) NULL,
   ElementName nvarchar2(255),
   NameFormat nvarchar2(64),
   CreationClassName  nvarchar2(256) NULL,
   Description  nvarchar2(512),
   Caption  nvarchar2(64),
   Status  nvarchar2(10),
   PrimaryOwnerContact  nvarchar2(256),
   PrimaryOwnerName  nvarchar2(64),
   dc_PrimaryOwnerPager  nvarchar2(32),
   dc_SystemLocation  nvarchar2(256),
   dc_HardwareCapability  nvarchar2(64),
   R_OverallStatus nvarchar2(50),
   R_ProductType nvarchar2(256),
   R_OperationalStatus nvarchar2(256),
   R_PortCount int,
   R_PortUtilized int,
   Domain nvarchar2(256),
   ReleaseDate nvarchar2(256),
  CONSTRAINT  CIM_ComputerSystem_pkey  PRIMARY KEY ( NodeID ,  SnapshotID ,  ComputerSystem_LUID )
)
GO
create index cim_computerSystem_ak on CIM_ComputerSystem(NodeId, SnapshotID, name, creationClassName)
GO
create index cim_luid ON CIM_ComputerSystem(computerSystem_LUID)
GO

-- Table:  CIM_FileSystem
CREATE TABLE  CIM_FileSystem  (
   FileSystem_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   Name  nvarchar2(256) NULL,
   CreationClassName  nvarchar2(256) NULL,
   CSCreationClassName  nvarchar2(256) NULL,
   CSName  nvarchar2(256) NULL,
   FileSystemSize  number(19),
   AvailableSpace  number(19),
   Description  nvarchar2(512),
   R_SizeMB  nvarchar2(256),
   R_UsedMB  nvarchar2(256),
   R_UsedPercent  nvarchar2(256),
   dc_SpaceUsed  number(19),
   dc_PercentSpaceUsed  int,
  CONSTRAINT  CIM_FileSystem_pkey  PRIMARY KEY ( FileSystem_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  CIM_IPRoute
CREATE TABLE  CIM_IPRoute  (
   IPRoute_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   CreationClassName  nvarchar2(256) NULL,
   ServiceCreationClassName  nvarchar2(256) NULL,
   ServiceName  nvarchar2(256) NULL,
   SystemCreationClassName  nvarchar2(256) NULL,
   SystemName  nvarchar2(256) NULL,
   IPDestinationAddress  nvarchar2(256) NULL,
   IPDestinationMask  nvarchar2(256) NULL,
   AddressType  smallint NULL,
   IsStatic  smallint,
   NextHop  nvarchar2(256),
   dc_RouteCount  nvarchar2(32),
   dc_RouteArgument  nvarchar2(1024),
  CONSTRAINT  CIM_IPRoute_pkey  PRIMARY KEY ( IPRoute_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  CIM_LogicalDevice
CREATE TABLE  CIM_LogicalDevice  (
   LogicalDevice_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   DeviceID  nvarchar2(64) NULL,
   CreationClassName  nvarchar2(256) NULL,
   SystemCreationClassName  nvarchar2(256) NULL,
   SystemName  nvarchar2(256) NULL,
   Name  nvarchar2(256) NULL,
   Caption  nvarchar2(64),
   Description  nvarchar2(512),
   Availability  smallint,
   LastErrorCode  int,
   dc_HardwareType  nvarchar2(64),
   OtherIdentifyingInfo  nvarchar2(256),
   dc_AssociatedDriver  nvarchar2(64),
  CONSTRAINT  CIM_LogicalDevice_pkey  PRIMARY KEY ( LogicalDevice_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  CIM_LogicalDisk


CREATE TABLE CIM_LogicalDisk (
    LogicalDisk_LUID number(19) NOT NULL,
    NodeID number(19) NOT NULL,
    SnapshotID number(19) NOT NULL,
    DeviceID nvarchar2(64) NULL,
    CreationClassName nvarchar2(256) NULL,
    SystemCreationClassName nvarchar2(256) NULL,
    SystemName nvarchar2(256) NULL,
    Win32_FreeSpace number(19) ,
    Win32_Size number(19) ,
    Description nvarchar2(512) ,
    R_SizeMB nvarchar2(256) ,
    R_UsedMB nvarchar2(256) ,
    R_UsedPercent nvarchar2(256) ,
    dc_SpaceUsed number(19) ,
    dc_PercentSpaceUsed int ,
    BlockSize number(19),
    NumberOfBlocks number(19),
  CONSTRAINT  CIM_LogicalDisk_pkey  PRIMARY KEY ( LogicalDisk_LUID, NodeID, SnapshotID )
)
GO

create index CIM_LD_node_snap_tag on CIM_LogicalDisk(NodeID, SnapshotID, DeviceID)
GO

-- Table:  CIM_MediaAccessDevice
CREATE TABLE  CIM_MediaAccessDevice  (
   MediaAccessDevice_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   DeviceID  nvarchar2(64) NULL,
   CreationClassName  nvarchar2(256) NULL,
   SystemCreationClassName  nvarchar2(256) NULL,
   SystemName  nvarchar2(256) NULL,
   Name  nvarchar2(256) NULL,
   Description  nvarchar2(512),
   MaxMediaSize  number(19),
   UnitsUsed  number(19),
   DefaultBlockSize  number(19),
   OtherIdentifyingInfo  nvarchar2(256),
   TotalPowerOnHours  number(19),
   UnitsDescription  nvarchar2(256),
   NeedsCleaning  smallint,
   Status  nvarchar2(10),
   MAStatInf_UnrecoverableWriteOp  int,
   MAStatInf_UnrecoverableReadOp  int,
   dc_Type  nvarchar2(64),
   dc_TransferMode  nvarchar2(64),
   r_DrivePort nvarchar2(256),
   r_Type nvarchar2(64),
   dc_RaidLevel varchar(64),
   ElementName nvarchar2(255),
  CONSTRAINT  CIM_MediaAccessDevice_pkey  PRIMARY KEY ( MediaAccessDevice_LUID ,  NodeID ,  SnapshotID )
)
GO

create index CIM_MA_node_snap_tag on CIM_MediaAccessDevice(NodeID, SnapshotID, DeviceID)
GO

create table operationalStatusMAD_values (
   OperationalStatusId number(19) not null,
   OperationalStatusValue number(5,0),
   OperationalStatusPos number(10,0) not null,
   primary key (OperationalStatusId, OperationalStatusPos)
)
GO

create table MediaAccessDev_SoftwareIdent (
   dependent number(19) not null,
   antecedent number(19) not null,
   primary key (dependent, antecedent)
)
GO

-- Table:  CIM_NetworkAdapter
CREATE TABLE  CIM_NetworkAdapter  (
   NetworkAdapter_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   CreationClassName  nvarchar2(256) NULL,
   DeviceID  nvarchar2(64) NOT NULL,
   SystemCreationClassName  nvarchar2(256) NULL,
   SystemName  nvarchar2(256) NULL,
   Name  nvarchar2(256) NULL,
   NetworkAddresses  nvarchar2(64),
   StatusInfo  smallint,
   PermanentAddress  nvarchar2(64),
   Caption  nvarchar2(64),
   EthernetAdp_InternalMACRcvErr  int,
   EthernetAdp_InternalMACTranErr  int,
   FullDuplex  smallint,
   OctetsTransmitted  number(19),
   OctetsReceived  number(19),
   MaxSpeed  number(19),
   IPProtocolEndpoint_SubnetMask  nvarchar2(64),
   dc_BroadcastAddress  nvarchar2(64),
   dc_DHCPEnabled  nvarchar2(32),
   R_InputErrors  nvarchar2(256),
   R_OutputErrors  nvarchar2(256),
   R_Duplex nvarchar2(25),
   R_MacAddress nvarchar2(64),
   dc_AdminStatus varchar(32),
   dc_OperStatus varchar(32),
   LANEndpoint_ProtocolType number(5,0),
   LANEndpoint_OperationalStatus nvarchar2(255),
   EthernetPort_PortType number(5,0),
   EthernetPort_MaxDataSize number(10,0),
  CONSTRAINT  CIM_NetworkAdapter_pkey  PRIMARY KEY ( NetworkAdapter_LUID ,  NodeID ,  SnapshotID )
)
GO

create index CIM_NA_node_snap_tag on CIM_NetworkAdapter(NodeID, SnapshotID, DeviceID)
GO

-- Table:  CIM_OperatingSystem
CREATE TABLE  CIM_OperatingSystem  (
   OperatingSystem_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   CSCreationClassName  nvarchar2(256) NULL,
   CSName  nvarchar2(256) NULL,
   CreationClassName  nvarchar2(256) NULL,
   Name  nvarchar2(256) NOT NULL,
   LastBootUpTime  number(19),
   LocalDateTime  number(19),
   Version  nvarchar2(64),
   Description  nvarchar2(512),
   OSType  smallint,
   NumberOfUsers  int,
   NumberOfProcesses  int,
   MaxNumberOfProcesses  number(19),
   CurrentTimeZone  smallint,
   TotalVisibleMemorySize  number(19),
   TotalSwapSpaceSize  number(19),
   OtherTypeDescription  nvarchar2(64),
   Caption  nvarchar2(64),
   dc_OperatingSystemCapability  nvarchar2(64),
   dc_OSType  nvarchar2(256),
   dc_PrimaryOS  smallint,
   Win32_CSDVersion  nvarchar2(256),
   dc_SwapSpaceName  nvarchar2(256),
   dc_SwapType  nvarchar2(64),
   dc_SwapSpaceMinimumSize  number(19),
   dc_SwapSpaceMaximumSize  number(19),
   dc_SwapSpaceReservedSize  number(19),
  CONSTRAINT  CIM_OperatingSystem_pkey  PRIMARY KEY ( OperatingSystem_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  CIM_PhysicalElement
CREATE TABLE  CIM_PhysicalElement  (
   PhysicalElement_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   CreationClassName  nvarchar2(256) NULL,
   Tag  nvarchar2(256) NOT NULL,
   Caption  nvarchar2(64),
   Description  nvarchar2(512),
   Name  nvarchar2(256),
   InstallDateTime  number(19),
   Status  nvarchar2(10),
   ManufactureDate  number(19),
   Manufacturer  nvarchar2(256),
   Model  nvarchar2(64),
   OtherIdentifyingInfo  nvarchar2(512),
   PartNumber  nvarchar2(256),
   PoweredOn  smallint,
   SerialNumber  nvarchar2(64),
   SKU  nvarchar2(64),
   Version  nvarchar2(64),
   Slot_Number  smallint,
   dc_Location  nvarchar2(64),
   dc_Condition  nvarchar2(64),
   dc_FirmwareRevision  nvarchar2(64),
   dc_HWLocation nvarchar2(256),
   dc_ProductId  nvarchar2(256),
  CONSTRAINT  CIM_PhysicalElement_pkey  PRIMARY KEY ( PhysicalElement_LUID ,  NodeID ,  SnapshotID )
)
GO

create index CIM_PE_node_snap_tag on CIM_PhysicalElement(NodeID, SnapshotID, Tag)
GO


-- Table:  CIM_PhysicalMedia
CREATE TABLE  CIM_PhysicalMedia  (
   PhysicalMedia_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   CreationClassName  nvarchar2(256) NULL,
   Tag  nvarchar2(256) NULL,
   MediaType  smallint,
   Capacity  number(19),
   Removable  smallint,
   OtherIdentifyingInfo  nvarchar2(512),
   Description  nvarchar2(512),
   Name  nvarchar2(256),
   HotSwappable  smallint,
   Manufacturer  nvarchar2(256),
   Model  nvarchar2(64),
   SerialNumber  nvarchar2(64),
   Version  nvarchar2(256),
  CONSTRAINT  CIM_PhysicalMedia_pkey  PRIMARY KEY ( PhysicalMedia_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  CIM_PhysicalMemory
CREATE TABLE  CIM_PhysicalMemory  (
   PhysicalMemory_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   CreationClassName nvarchar2(256) NULL,
   Tag  nvarchar2(256) NOT NULL,
   MemoryType  smallint,
   Capacity  number(19),
   R_MemoryType  nvarchar2(256),
   R_MemoryTech  nvarchar2(256),
   FormFactor  smallint,
   PartNumber  nvarchar2(256),
   SerialNumber  nvarchar2(64),
   dc_ErrorMethodology  nvarchar2(512),
   dc_HWLocation nvarchar2(256),
   R_Slot smallint,
   Description nvarchar2(255),
   BankLabel nvarchar2(64),
   MemLoc_LocationIdentifiers nvarchar2(255),
  CONSTRAINT  CIM_PhysicalMemory_pkey  PRIMARY KEY ( PhysicalMemory_LUID ,  NodeID ,  SnapshotID )
)
GO

create index CIM_PM_node_snap_tag on CIM_PhysicalMemory(NodeID, SnapshotID, Tag)
GO

-- Table:  CIM_PowerSupply
CREATE TABLE  CIM_PowerSupply  (
   PowerSupply_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   CreationClassName  nvarchar2(256) NULL,
   DeviceID  nvarchar2(64) NOT NULL,
   SystemCreationClassName  nvarchar2(256) NULL,
   SystemName  nvarchar2(256) NULL,
   Name  nvarchar2(256) NULL,
   Availability  smallint,
   AdditionalAvailability  smallint,
   TotalOutputPower  int,
   R_Status  nvarchar2(256),
   R_Condition  nvarchar2(256),
   R_MaxCapacity  nvarchar2(256),
   dc_PowerSupplyPresent nvarchar2(32),
   dc_PowerSupplyStatus  nvarchar2(64),
   dc_RedundancyState  nvarchar2(32),
   dc_CurrentOutputPower  int,
   OtherIdentifyingInfo nvarchar2(256),
  CONSTRAINT  CIM_PowerSupply_pkey  PRIMARY KEY ( PowerSupply_LUID ,  NodeID ,  SnapshotID )
)
GO

create index CIM_PS_node_snap_tag on CIM_PowerSupply(NodeID, SnapshotID, DeviceID)
GO

-- Table:  CIM_Process
CREATE TABLE  CIM_Process  (
   Process_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   CSCreationClassName  nvarchar2(256) NULL,
   CSName  nvarchar2(256) NULL,
   OSCreationClassName  nvarchar2(256) NULL,
   OSName  nvarchar2(256) NULL,
   Handle  nvarchar2(256) NULL,
   CreationClassName  nvarchar2(256) NULL,
   Name  nvarchar2(256),
   ExecutionState  smallint,
   Priority  int,
   UnixProcess_ParentProcessID  nvarchar2(256),
   UnixProcess_ProcessGroupID  number(19),
   UnixProcess_RealUserID  number(19),
   UnixProcess_ProcessTTY  nvarchar2(32),
   UnixProcess_ModulePath  nvarchar2(512),
   OtherExecutionDescription nvarchar2(512),
   UnixProcess_Parameters  nvarchar2(512),
   UnixProcess_ProcessNiceValue  int,
   UxPrStatInf_RealStack  number(19),
   UxPrStatInf_VirText  number(19),
   UxPrStatInf_VirData  number(19),
   UxPrStatInf_VirStack  number(19),
   UxPrStatInf_VirSharedMem  number(19),
   UxPrStatInf_VirMemMapFileSize  number(19),
  CONSTRAINT  CIM_Process_pkey  PRIMARY KEY ( Process_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  CIM_Processor
CREATE TABLE  CIM_Processor  (
   Processor_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   CreationClassName  nvarchar2(256) NULL,
   DeviceID  nvarchar2(64) NULL,
   Name  nvarchar2(256) NULL,
   SystemCreationClassName  nvarchar2(256) NULL,
   SystemName  nvarchar2(256) NULL,
   Family  smallint,
   CurrentClockSpeed  int,
   UniqueID  nvarchar2(256),
   LoadPercentage  smallint,
   CPUStatus  smallint,
   OtherIdentifyingInfo  nvarchar2(256),
   dc_HWLocation nvarchar2(256),
   R_CPUType  nvarchar2(256),
   R_CPUSpeed  nvarchar2(256),
   R_CPUStatus  nvarchar2(256),
   ArchitectureRevision number(5,0),
   FirmwareRevision nvarchar2(255),
   DataWidth number(5,0),
   ProcessorLocation_CellNumber nvarchar2(255),
  CONSTRAINT  CIM_Processor_pkey  PRIMARY KEY ( Processor_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  CIM_Rack
CREATE TABLE  CIM_Rack  (
   Rack_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   CreationClassName  nvarchar2(256) NULL,
   Tag  nvarchar2(256) NULL,
   SerialNumber  nvarchar2(64),
   Name  nvarchar2(256),
  CONSTRAINT  CIM_Rack_pkey  PRIMARY KEY ( Rack_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  CIM_Sensor
CREATE TABLE  CIM_Sensor  (
   Sensor_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   DeviceID  nvarchar2(64) NOT NULL,
   CreationClassName  nvarchar2(256) NULL,
   SystemCreationClassName nvarchar2(256) NULL,
   SystemName  nvarchar2(256) NULL,
   Name  nvarchar2(256) NULL,
   Status  nvarchar2(10),
   CurrentState  nvarchar2(128),
   PossibleStates  nvarchar2(512),
   CurrentReading int,
   dc_OtherCurrentReading int,
   BaseUnit int,
   SensorType number(5,0),
  CONSTRAINT  CIM_Sensor_pkey  PRIMARY KEY ( Sensor_LUID ,  NodeID ,  SnapshotID )
)
GO

create index CIM_Sensor_node_snap_tag on CIM_Sensor(NodeID, SnapshotID, DeviceID)
GO

-- Table:  CIM_SoftwareElement
CREATE TABLE  CIM_SoftwareElement  (
   SoftwareElement_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   SoftwareElementID  nvarchar2(256) NOT NULL,
   SoftwareElementState  smallint NULL,
   Version  nvarchar2(64) NULL,
   Name  nvarchar2(256) NULL,
   TargetOperatingSystem  smallint NULL,
   InstallDate  number(19),
   R_Date  nvarchar2(256),
   R_Status  nvarchar2(256),
   Description  nvarchar2(512),
   DeviceSW_Purpose  smallint,
   DeviceSW_PurposeDescription nvarchar2(512),
   swd_VersionWeight  int,
   dc_OtherVersionInfo  nvarchar2(64),
   R_Type nvarchar2(64),
  CONSTRAINT  CIM_SoftwareElement_pkey  PRIMARY KEY ( SoftwareElement_LUID ,  NodeID ,  SnapshotID )
)
GO

create index CIM_SW_node_snap_tag on CIM_SoftwareElement(NodeID, SnapshotID, SoftwareElementID)
GO

-- Table:  DC_ProliantHost
CREATE TABLE  DC_ProliantHost  (
   ProliantHost_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   dc_SystemCreationClassName  nvarchar2(256) NULL,
   dc_SystemName  nvarchar2(256) NULL,
   OverallCondition  nvarchar2(16),
   MIBStatusArray  nvarchar2(512),
   GUID  nvarchar2(64),
   WebManagementPort  int,
   ASRStatus  nvarchar2(16),
   SystemID  int,
   ServerRole  nvarchar2(64),
   ServerRoleDetail  nvarchar2(512),
   ConfigChangeDate  number(19),
   SystemUptime  number(19),
  CONSTRAINT  DC_ProliantHost_pkey  PRIMARY KEY ( ProliantHost_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  HPUX_BaseKernelParameter
CREATE TABLE  HPUX_BaseKernelParameter  (
   BaseKernelParameter_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   BaseKernelParameterID  int NULL,
   SettingID  nvarchar2(256),
   CurrentValue  nvarchar2(256),
  CONSTRAINT  HPUX_BaseKernelParameter_pkey  PRIMARY KEY ( BaseKernelParameter_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  HPUX_Bundle
-- changed size to Size_ due to size being a reserved word...
CREATE TABLE  HPUX_Bundle  (
   Bundle_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   IdentifyingNumber  nvarchar2(256) NULL,
   Version  nvarchar2(64) NULL,
   Vendor  nvarchar2(256) NULL,
   Name  nvarchar2(256),
   Architecture  nvarchar2(64),
   Location  nvarchar2(256),
   QualifierID  nvarchar2(64),
   CreateTime  number(19),
   Description  nvarchar2(512),
   ModificationTime  number(19),
   Size_  nvarchar2(32),
   Caption  nvarchar2(128),
   Copyright  nvarchar2(256),
   Directory  nvarchar2(256),
   InstanceIdentifier  nvarchar2(16),
   IsLocatable  smallint,
   LayoutVersion  nvarchar2(64),
   MachineType  nvarchar2(64),
   SKUNumber  nvarchar2(64),
   OperatingSystemName  nvarchar2(256),
   OperatingSystemRelease  nvarchar2(256),
   OperatingSystemVersion  nvarchar2(64),
   IsPatch  smallint,
   InstallSource  nvarchar2(256),
   DataModelRevision  nvarchar2(64),
   InstallDate  number(19),
   Contents  varchar(512),
  CONSTRAINT  HPUX_Bundle_pkey  PRIMARY KEY ( Bundle_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  HPUX_DNSService
CREATE TABLE  HPUX_DNSService  (
   DNSService_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   SystemCreationClassName  nvarchar2(256) NULL,
   SystemName  nvarchar2(256) NULL,
   Name  nvarchar2(256) NULL,
   SearchList  nvarchar2(512),
   Addresses  nvarchar2(512),
  CONSTRAINT  HPUX_DNSService_pkey  PRIMARY KEY ( DNSService_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  HPUX_Fileset
-- changed name from Size to Size_ since size is a reserved word
CREATE TABLE  HPUX_Fileset  (
   Fileset_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   SoftwareElementID  nvarchar2(256) NULL,
   Name  nvarchar2(256) NULL,
   Version  nvarchar2(64) NULL,
   TargetOperatingSystemName  smallint NULL,
   CreateTime  number(19),
   Description  nvarchar2(512),
   ModificationTime  number(19),
   Size_ nvarchar2(32),
   Caption  nvarchar2(128),
   ControlDirectory nvarchar2(256),
   IsKernel  smallint,
   IsLocatable  smallint,
   IsReboot  smallint,
   Location  nvarchar2(256),
   MediaSequenceNumber  nvarchar2(256),
   SoftwareElementState  smallint,
   DataModelRevision  nvarchar2(64),
   InstanceIdentifier  nvarchar2(16),
   InstallDate  number(19),
   Architecture  nvarchar2(64),
   MachineType  nvarchar2(64),
   OperatingSystemName  nvarchar2(256),
   OperatingSystemRelease  nvarchar2(256),
   OperatingSystemVersion  nvarchar2(64),
   InstallSource  nvarchar2(128),
   IsPatch  smallint,
   IsSparse  smallint,
   PatchState  nvarchar2(16),
   AppliedPatches  nvarchar2(256),
   SupercededBy  nvarchar2(256),
   SavedFilesDirectory  nvarchar2(256),
  CONSTRAINT  HPUX_Fileset_pkey  PRIMARY KEY ( Fileset_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  HPUX_HFS
CREATE TABLE  HPUX_HFS  (
   HFS_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   Name  nvarchar2(256) NULL,
   CreationClassName  nvarchar2(256) NULL,
   CSCreationClassName  nvarchar2(256) NULL,
   CSName  nvarchar2(256) NULL,
   Root  nvarchar2(256),
   ReadOnly  smallint,
   FileSystemType  nvarchar2(256),
   FileSystemSize  number(19),
   BlockSize  number(19),
   AvailableSpace  number(19),
   RemoteFileSystem_Name  nvarchar2(256),
   FreeInodes  number(19),
   TotalInodes  number(19),
   FSReservedCapacity  number(19),
   Bootable  smallint,
   LargeFilesSupported  smallint,
   MinimumFreeSpace  smallint,
   FragmentSize  int,
   InodeSize  int,
   SectorsPerTrack  int,
   TracksPerCylinder  int,
   DiskCylindersPerCylinderGroup  int,
   DiskRevolutionsPerSecond  int,
   RotationalDelay  int,
   dc_MountedFileSystems  int,
  CONSTRAINT  HPUX_HFS_pkey  PRIMARY KEY ( HFS_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  HPUX_LogicalVolume
-- changed Access to Access_ since access is a reserved word
CREATE TABLE  HPUX_LogicalVolume  (
   LogicalVolume_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   Name  nvarchar2(256) NULL,
   DeviceID nvarchar2(64),
   Access_  smallint,
   LogicalExtentSize  number(19),
   Capacity  number(19),
   MirrorCopyNumber  int,
   ConsistencyRecovery  nvarchar2(64),
   SchedulePolicy  nvarchar2(64),
   NumberOfStripes  int,
   StripeSize  int,
   BadBlockRelocation  smallint,
   AllocationPolicy  nvarchar2(64),
   StaledLogicalExtent  int,
   NumberReadAccesses  int,
   NumberWriteAccesses  int,
   Status  nvarchar2(64),
   BlockSize number(19),
   NumberOfBlocks number(19),
  CONSTRAINT  HPUX_LogicalVolume_pkey  PRIMARY KEY ( LogicalVolume_LUID ,  NodeID ,  SnapshotID )
)
 GO

-- Table:  HPUX_NISServerService
CREATE TABLE  HPUX_NISServerService  (
   NISServerService_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   Name  nvarchar2(256) NULL,
   SystemCreationClassName nvarchar2(256) NULL,
   SystemName  nvarchar2(256) NULL,
   CreationClassName  nvarchar2(256) NULL,
   ServerWaitFlag  smallint,
   Caption nvarchar2(64),
   Description  nvarchar2(512),
   ServerType  smallint,
  CONSTRAINT  HPUX_NISServerService_pkey  PRIMARY KEY ( NISServerService_LUID ,  SnapshotID ,  NodeID )
)
GO

-- Table:  HPUX_NTPService
CREATE TABLE  HPUX_NTPService  (
   NTPService_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   SystemCreationClassName  nvarchar2(256) NULL,
   SystemName  nvarchar2(256) NULL,
   CreationClassName  nvarchar2(256) NULL,
   Name  nvarchar2(256) NOT NULL,
   Caption  nvarchar2(64),
   ServerAddress  nvarchar2(512),
   Description  nvarchar2(512),
  CONSTRAINT  HPUX_NTPService_pkey  PRIMARY KEY ( NTPService_LUID ,  SnapshotID ,  NodeID )
)
GO

-- Table:  HPUX_PhysicalVolume
CREATE TABLE  HPUX_PhysicalVolume  (
   PhysicalVolume_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   Name  nvarchar2(256) NULL,
   DeviceID  nvarchar2(64),
   AlternatePVName  nvarchar2(256),
   Status  nvarchar2(32),
   PhysicalExtentSize  number(19),
   Capacity  number(19),
   Allocated  int,
   Free  int,
   NumberStaledPEs  int,
   BlockSize number(19),
   NumberOfBlocks number(19),
  CONSTRAINT  HPUX_PhysicalVolume_pkey  PRIMARY KEY ( PhysicalVolume_LUID ,  NodeID ,  SnapshotID )
)
 GO

-- Table:  HPUX_Product
-- changed Size to Size_ since Size is a reserved word
CREATE TABLE  HPUX_Product  (
   Product_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   IdentifyingNumber  nvarchar2(256) NULL,
   Name  nvarchar2(256) NULL,
   Version  nvarchar2(64) NULL,
   Vendor  nvarchar2(256) NULL,
   Architecture  nvarchar2(64),
   Location  nvarchar2(256),
   QualifierID  nvarchar2(64),
   CreateTime  number(19),
   Description  nvarchar2(512),
   ModificationTime  number(19),
   Size_  nvarchar2(32),
   Caption  nvarchar2(128),
   AllFilesets  nvarchar2(512),
   ControlDirectory  nvarchar2(256),
   Copyright  nvarchar2(256),
   Directory  nvarchar2(256),
   InstanceIdentifier  nvarchar2(16),
   IsLocatable  smallint,
   PostKernelPath  nvarchar2(256),
   LayoutVersion  nvarchar2(64),
   MachineType  nvarchar2(64),
   SKUNumber  nvarchar2(64),
   OperatingSystemName  nvarchar2(256),
   OperatingSystemRelease  nvarchar2(256),
   OperatingSystemVersion  nvarchar2(64),
   IsPatch  smallint,
   InstallSource  nvarchar2(128),
   DataModelRevision  nvarchar2(8),
   InstallDate  number(19),
  CONSTRAINT  HPUX_Product_pkey  PRIMARY KEY ( Product_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  HPUX_VolumeGroup
CREATE TABLE  HPUX_VolumeGroup  (
   VolumeGroup_LUID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   CollectionID  nvarchar2(64) NULL,
   Name  nvarchar2(256) NULL,
   AccessPermission  nvarchar2(64),
   Status  nvarchar2(32),
   PhysicalExtentSize  int,
   Capacity  int,
   Allocated  int,
   FreeSpace  int,
   MaxNumberOfPVs  int,
   MaxPEsPerPV  int,
   NumberOfDefinedPVs  int,
   NumberOfActivePVs  int,
   MaxNumberOfLVs  int,
   NumberOfDefinedLVs  int,
   NumberOfActiveLVs  int,
   NumberOfPVGroups  int,
  CONSTRAINT  HPUX_VolumeGroup_pkey  PRIMARY KEY ( VolumeGroup_LUID ,  NodeID ,  SnapshotID )
)
GO

-- Table:  NodeSnapshot
CREATE TABLE  NodeSnapshot  (
   SnapshotID  number(19) NOT NULL,
   NodeID  number(19) NOT NULL,
   Tag  nvarchar2(256),
   Description  nvarchar2(512),
   CollectionDateTime  number(19),
   DetailedInformation  nvarchar2(512),
   ReturnCode  smallint,
   Status  nvarchar2(256),
   DataAvailable  int,
   FilterID  number(19),
  CONSTRAINT  NodeSnapshot_pkey  PRIMARY KEY ( NodeID ,  SnapshotID )
)
GO

-- Table:  Snapshot
CREATE TABLE  Snapshot  (
   SnapshotID  number(19) NOT NULL,
   OverallStatus  nvarchar2(64),
   SnapshotTag  nvarchar2(256),
   CollectionDateTime  number(19),
  CONSTRAINT  Snapshot_pkey  PRIMARY KEY ( SnapshotID )
)
GO

---- -----------------------------------------------------------------------------------------------------------
---- Changes for adding IPF NPar data in Data Collection
---- -----------------------------------------------------------------------------------------------------------
CREATE TABLE HP_NParCell (
    NParCell_LUID  number(19) NOT NULL,
    NodeID  number(19) NOT NULL,
    SnapshotID  number(19) NOT NULL,
    SlotID  int NULL,
    TotalMemoryInstalled  number(19),
    MaxCPUCount  int,
    CPUCount smallint,
    CPUSpeed int,
    FirmwareRevision nvarchar2(256),
    DIMMSlotPopulated  nvarchar2(256),
    CPUSlotPopulated  nvarchar2(256),
    ConnectedToIOChassis  number(1,0),
    ConnectedIOChassisID  int,
    CellArchitecture  smallint,
    ComponentStatus  smallint,
  CONSTRAINT  HP_NParCell_pkey  PRIMARY KEY ( NParCell_LUID ,  NodeID ,  SnapshotID )
)
GO

CREATE TABLE HP_NParIOChassisSlot (
    NParIOChassisSlot_LUID number(19) NOT NULL,
    NodeID number(19) NOT NULL,
    SnapshotID  number(19) NOT NULL,
    ID int NULL,
    CabinetID int,
    IOBayNumber int,
    Number_ int,
  CONSTRAINT  HP_NParIOChassisSlot_pkey  PRIMARY KEY ( NParIOChassisSlot_LUID ,  NodeID ,  SnapshotID )
)
GO

CREATE TABLE HP_NParPartition (
    NParPartition_LUID  number(19) NOT NULL,
    NodeID number(19) NOT NULL,
    SnapshotID  number(19) NOT NULL,
    PartitionID  int NULL,
    dc_TotalCPU int,
    dc_InstalledCells int,
    dc_PoweredOnCells int,
    PartitionName nvarchar2(256),
    dc_CoreCell int,
    dc_CoreCellCabinet int,
    dc_HasInterleaveMem int,
    r_dc_HasInterleaveMem nvarchar2(256) NULL,
    PartitionNameLabel nvarchar2(256),
    PartitionType smallint,
    PartitionIsDefined smallint,
    CoreCellID int,
    PrimaryBootPath nvarchar2(256),
    AlternateBootPath nvarchar2(256),
    HAAlternateBootPath nvarchar2(256),
  CONSTRAINT  HP_NParPartition_pkey  PRIMARY KEY ( NParPartition_LUID ,  NodeID ,  SnapshotID )
)
GO

CREATE TABLE HP_NParComplex (
    NParComplex_LUID number(19) NOT NULL,
    NodeID number(19) NOT NULL,
    SnapshotID  number(19) NOT NULL,
    ProfileID  int NULL,
    dc_ComputeCabCount int,
    dc_IOXCabCount int,
    ComplexName nvarchar2(256),
    RevisionString nvarchar2(256),
    MaxPartitionsSupported smallint,
    CreatorSerialNumber nvarchar2(256),
    CreatorProductName nvarchar2(256),
    OEMSerialNumber nvarchar2(256),
    OEMProductName nvarchar2(256),
    OriginalProductOrderNumber nvarchar2(256),
    CurrentProductOrderNumber nvarchar2(256),
    UUID nvarchar2(128),
    CellAssignments nvarchar2(256),
  CONSTRAINT  HP_NParComplex_pkey  PRIMARY KEY ( NParComplex_LUID ,  NodeID ,  SnapshotID )
)
GO

CREATE TABLE HP_NParIOChassis (
   NParIOChassis_LUID number(19) NOT NULL,
   NodeID number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   ConnectedCellID int NULL,
   PopulatedPCISlotCount smallint,
 CONSTRAINT NParIOChassis_pkey PRIMARY KEY ( NParIOChassis_LUID , NodeID , SnapshotID )
)
GO

CREATE TABLE HP_NParCabinet (
   NParCabinet_LUID number(19) NOT NULL,
   NodeID number(19) NOT NULL,
   SnapshotID  number(19) NOT NULL,
   CabinetType int NULL,
   Label nvarchar2(256),
   ServiceProcessorCount nvarchar2(256),
   ServiceProcessorLocation nvarchar2(1024),
   ServiceProcessorStatus nvarchar2(256),
 CONSTRAINT NParCabinet_pkey PRIMARY KEY ( NParCabinet_LUID , NodeID , SnapshotID )
)
GO

---- ----------------------------------------------------------------------------------------
----  new ServiceGuard Cluster DC data
---- ----------------------------------------------------------------------------------------
 CREATE TABLE  HP_Cluster (
     HPCluster_LUID number(19) NOT NULL,
     NodeID number(19) NOT NULL,
     SnapshotID number(19) NOT NULL,
     MembershipIncarnation number(19) NULL,
     Name nvarchar2(256),
     Interconnect nvarchar2(256),
     dc_Types nvarchar2(256),
 CONSTRAINT  HPCluster_pkey  PRIMARY KEY (HPCluster_LUID, NodeID, SnapshotID)
)
GO

 CREATE TABLE  HP_Node (
     HPNode_LUID number(19) NOT NULL,
     NodeID number(19) NOT NULL,
     SnapshotID number(19) NOT NULL,
     Name nvarchar2(256) NULL,
     MemberName nvarchar2(256),
     MemberID int,
 CONSTRAINT HPNode_pkey  PRIMARY KEY (HPNode_LUID, NodeID, SnapshotID)
)
GO

---- ----------------------------------------------------------------------------------------


--  add Report views
--  R_InstalledBoards, R_TmpRacEnclBlade, R_tmpBlade must define before all others(R_xxxxx) Views

CREATE VIEW R_InstalledBoards
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_PhysicalElement.Name AS BoardName,
               CIM_PhysicalElement.Model AS BoardModel, CIM_PhysicalElement.Version AS BoardRevision,
               CIM_PhysicalElement.dc_FirmwareRevision AS BoardFirmware, CIM_PhysicalElement.SerialNumber AS BoardSerial,
               CIM_PhysicalElement.Slot_Number AS Slot, CIM_PhysicalElement.SnapshotID, CIM_PhysicalElement.dc_HWLocation AS Location,
               CIM_PhysicalElement.Tag
FROM  CIM_PhysicalElement LEFT OUTER JOIN
               devices ON CIM_PhysicalElement.NodeID = devices.DeviceKey
WHERE (NOT (CIM_PhysicalElement.Name IS NULL)) AND (CIM_PhysicalElement.Tag NOT LIKE '%Drive%') AND
               (CIM_PhysicalElement.Tag NOT LIKE '%Blade%') AND (CIM_PhysicalElement.Tag NOT LIKE '%Power%') AND
               (NOT (CIM_PhysicalElement.Tag LIKE '%Connector%')) AND (NOT (CIM_PhysicalElement.Tag LIKE '%Storage%')) AND
               (NOT (CIM_PhysicalElement.Name LIKE '%bridge%')) AND (NOT (CIM_PhysicalElement.Name LIKE '%PROCESSOR MODULES%')) AND
               (NOT (CIM_PhysicalElement.Name LIKE '%Other%')) AND (NOT (CIM_PhysicalElement.Tag LIKE '%EISA Board 0%')) OR
               (CIM_PhysicalElement.Tag NOT LIKE '%Drive%') AND (CIM_PhysicalElement.Tag NOT LIKE '%Blade%') AND
               (CIM_PhysicalElement.Tag NOT LIKE '%Power%') AND (NOT (CIM_PhysicalElement.Tag LIKE '%Connector%')) AND
               (NOT (CIM_PhysicalElement.Tag LIKE '%Storage%')) AND (NOT (CIM_PhysicalElement.Model IS NULL)) AND
               (NOT (CIM_PhysicalElement.Tag LIKE '%EISA Board 0%')) OR
               (CIM_PhysicalElement.Tag LIKE '%Controller%')
)
GO

CREATE VIEW R_TmpRacEnclBlade
AS(
SELECT CIM_Chassis.Chassis_LUID, CIM_Chassis.NodeID, CIM_Chassis.dc_SystemName, CIM_Rack.Name AS RackName,
               CIM_Chassis.Name, CIM_Chassis.R_Model AS Model, CIM_Chassis.SerialNumber, CIM_Chassis.ChassisTypes,
               CIM_Chassis.SnapshotID, CIM_Chassis.Tag
FROM  CIM_Chassis INNER JOIN
               CIM_Rack ON CIM_Chassis.NodeID = CIM_Rack.NodeID AND CIM_Chassis.SnapshotID = CIM_Rack.SnapshotID
WHERE (CIM_Chassis.Tag LIKE '%Enclosure%') OR
               (CIM_Chassis.ChassisTypes = '23')
)
GO


CREATE VIEW R_TmpBlade
AS(
SELECT CIM_Chassis.Chassis_LUID, CIM_Chassis.NodeID, CIM_Chassis.dc_SystemName,
               CIM_PhysicalElement.dc_Location AS EnclosureName, CIM_Chassis.R_Model AS Model, CIM_Chassis.ChassisTypes,
               CIM_PhysicalElement.Slot_Number, CIM_PhysicalElement.Tag, CIM_Chassis.SnapshotID
FROM  CIM_Chassis INNER JOIN
               CIM_PhysicalElement ON CIM_Chassis.NodeID = CIM_PhysicalElement.NodeID AND
               CIM_Chassis.SnapshotID = CIM_PhysicalElement.SnapshotID AND
               CIM_Chassis.SerialNumber = CIM_PhysicalElement.SerialNumber
WHERE (CIM_Chassis.ChassisTypes = '23')
)
GO


CREATE VIEW R_ArrayControllers
AS(
SELECT DeviceKey, DeviceName, BoardName, BoardModel AS Model, BoardRevision AS Version, BoardFirmware AS FirmwareRev,
               BoardSerial AS SerialNumber, Slot AS SlotNumber, SnapshotID, Tag
FROM  R_InstalledBoards
WHERE (Tag LIKE '%NetRaid%') OR
               (BoardName LIKE '%Array%') OR
               (Tag LIKE '%Array%') OR
               (BoardName LIKE '%NetRaid%')
)
GO


CREATE VIEW R_Batteries
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_PhysicalElement.SerialNumber,
               CIM_PhysicalElement.OtherIdentifyingInfo AS AssetNumber,
               CIM_PhysicalElement.SnapshotID, CIM_PhysicalElement.Tag
FROM  CIM_PhysicalElement LEFT OUTER JOIN
               devices ON CIM_PhysicalElement.NodeID = devices.DeviceKey
WHERE (CIM_PhysicalElement.Tag LIKE '%Battery%')
)
GO

CREATE VIEW R_CPU
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_Processor.Name AS CPUType,
               CIM_Processor.CurrentClockSpeed AS CPUSpeed, CIM_Processor.OtherIdentifyingInfo AS SlotNumber,
               CIM_Processor.SnapshotID, CIM_Processor.Family AS FirmwareID, CIM_Processor.LoadPercentage AS ProcessorLoad,
               CIM_Processor.R_CPUStatus AS ProcessorAllocated, CIM_Processor.dc_HWLocation AS Location
FROM  CIM_Processor LEFT OUTER JOIN
               devices ON CIM_Processor.NodeID = devices.DeviceKey
)
GO



CREATE VIEW R_DIMMSlots
AS(
SELECT     devices.DeviceKey, devices.Name AS DeviceName, CIM_PhysicalMemory.FormFactor,
                      CIM_PhysicalMemory.Capacity / 1024 AS MemorySize, CIM_PhysicalMemory.PartNumber, CIM_PhysicalMemory.SerialNumber,
                      CIM_PhysicalMemory.R_Slot AS SlotNumber, CIM_PhysicalMemory.R_MemoryType AS MemoryType,
                      CIM_PhysicalMemory.R_MemoryTech AS MemoryTech, CIM_PhysicalMemory.dc_HWLocation AS Location,
                      CIM_PhysicalMemory.SnapshotID
FROM         CIM_PhysicalMemory LEFT OUTER JOIN
                      devices ON CIM_PhysicalMemory.NodeID = devices.DeviceKey
)
GO

CREATE VIEW R_LogicalDisks
AS(
    SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_LogicalDisk.Description,
    DECODE( CIM_LogicalDisk.Win32_Size / 1048576,NULL, (DECODE(CIM_LogicalDisk.BlockSize,NULL,0,CIM_LogicalDisk.BlockSize) * DECODE(CIM_LogicalDisk.NumberOfBlocks,NULL,0,CIM_LogicalDisk.NumberOfBlocks) / 1048576) , CIM_LogicalDisk.Win32_Size / 1048576) AS SizeMB,
    CIM_LogicalDisk.dc_SpaceUsed / 1048576 AS UsedMB,
    CIM_LogicalDisk.dc_PercentSpaceUsed AS UsedPercent,
    CIM_LogicalDisk.SnapshotID
FROM  CIM_LogicalDisk LEFT OUTER JOIN
    devices ON CIM_LogicalDisk.NodeID = devices.DeviceKey
)
GO

-- IPAddress.MACaddr in char, CIM_NetworkAdapter.R_MacAddress must also in char
CREATE VIEW R_NetworkInterface
AS(
SELECT CIM_NetworkAdapter.NodeID AS DeviceKey, CIM_NetworkAdapter.SystemName AS DeviceName,
       CIM_NetworkAdapter.Caption AS Description, CIM_NetworkAdapter.PermanentAddress AS MacAddress,
       IPAddress.IPAddress, CIM_NetworkAdapter.EthernetAdp_InternalMACRcvErr AS InputErrors,
       CIM_NetworkAdapter.EthernetAdp_InternalMACTranErr AS OutputErrors,
       CIM_NetworkAdapter.MaxSpeed AS Speed, CIM_NetworkAdapter.R_Duplex AS Duplex,
       CIM_NetworkAdapter.FullDuplex, CIM_NetworkAdapter.Name AS InterfaceName,
       CIM_NetworkAdapter.IPProtocolEndpoint_SubnetMask AS SubnetMask,
       CIM_NetworkAdapter.dc_BroadcastAddress AS BroadcastAddress,
       CIM_NetworkAdapter.StatusInfo AS InterfaceState, CIM_NetworkAdapter.dc_DHCPEnabled AS DHCPEnabled,
       IPAddress.IPAddressNumber AS IPLongValue, CIM_NetworkAdapter.SnapshotID,
       CIM_NetworkAdapter.LANEndpoint_OperationalStatus AS OperationalStatus,
       CIM_NetworkAdapter.LANEndpoint_ProtocolType AS ProtocolType,
       CIM_NetworkAdapter.EthernetPort_MaxDataSize AS MaxDataSize,
       CIM_NetworkAdapter.EthernetPort_PortType AS PortType
FROM   IPAddress RIGHT OUTER JOIN
       CIM_NetworkAdapter ON IPAddress.DeviceKey = CIM_NetworkAdapter.NodeID AND
       IPAddress.MACaddr = CIM_NetworkAdapter.R_MacAddress
WHERE  (NOT (CIM_NetworkAdapter.Caption LIKE '%ppp%')) AND
                      (NOT (CIM_NetworkAdapter.Caption LIKE '%Loopback%')) OR
                      (CIM_NetworkAdapter.Caption IS NULL)
)
GO


CREATE VIEW R_OperatingSystem
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_OperatingSystem.Name AS Description, CIM_OperatingSystem.Version,
               CIM_OperatingSystem.Description AS SubDesc, CIM_OperatingSystem.dc_OSType AS OSType, CIM_OperatingSystem.SnapshotID,
               DB_DeviceInfoEx.OSVendor
FROM  DB_DeviceInfoEx INNER JOIN
               devices ON DB_DeviceInfoEx.DeviceKey = devices.DeviceKey LEFT OUTER JOIN
               CIM_OperatingSystem ON devices.DeviceKey = CIM_OperatingSystem.NodeID
)
GO

CREATE VIEW R_PCIBoards
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_PhysicalElement.Name AS BoardName,
               CIM_PhysicalElement.Slot_Number AS SlotNumber, CIM_PhysicalElement.SnapshotID, CIM_PhysicalElement.Tag
FROM  CIM_PhysicalElement LEFT OUTER JOIN
               devices ON CIM_PhysicalElement.NodeID = devices.DeviceKey
WHERE (CIM_PhysicalElement.Tag LIKE '%PCI%')
)
GO

CREATE VIEW R_PhysicalDisks
AS(
SELECT CIM_MediaAccessDevice.NodeID AS DeviceKey, CIM_MediaAccessDevice.SystemName AS DeviceName,
               CIM_MediaAccessDevice.r_Type AS DeviceType, CIM_PhysicalElement.Model AS DriveModel,
               CIM_MediaAccessDevice.MaxMediaSize / 1000 AS DriveSize,
               DECODE(CIM_PhysicalElement.dc_FirmwareRevision,NULL,CIM_PhysicalElement.Version,CIM_PhysicalElement.dc_FirmwareRevision) AS DriveFirmware,
               CIM_MediaAccessDevice.dc_TransferMode AS TransferMode, CIM_PhysicalElement.SerialNumber AS DriveSerial,
               CIM_PhysicalElement.Manufacturer AS DriveVendor, CIM_PhysicalElement.Slot_Number AS Slot,
               CIM_PhysicalElement.dc_Location AS DriveLoc, CIM_MediaAccessDevice.r_DrivePort AS DrivePort,
               CIM_Chassis.Name AS DriveChassis, CIM_MediaAccessDevice.TotalPowerOnHours AS DriveServiceTime,
               CIM_MediaAccessDevice.MAStatInf_UnrecoverableReadOp AS HardReadErrors,
               CIM_MediaAccessDevice.MAStatInf_UnrecoverableWriteOp AS HardWriteErrors, CIM_MediaAccessDevice.DeviceID,
               CIM_MediaAccessDevice.SnapshotID
FROM  CIM_MediaAccessDevice LEFT OUTER JOIN
               CIM_PhysicalElement ON CIM_MediaAccessDevice.DeviceID = CIM_PhysicalElement.Tag AND
               CIM_MediaAccessDevice.NodeID = CIM_PhysicalElement.NodeID AND
               CIM_MediaAccessDevice.SnapshotID = CIM_PhysicalElement.SnapshotID LEFT OUTER JOIN
               CIM_Chassis ON CIM_PhysicalElement.NodeID = CIM_Chassis.NodeID AND
               CIM_PhysicalElement.SnapshotID = CIM_Chassis.SnapshotID AND CIM_PhysicalElement.Tag = CIM_Chassis.Tag
WHERE (NOT (CIM_MediaAccessDevice.DeviceID LIKE '%Logical%'))
)
GO

CREATE VIEW R_Racks
AS(
SELECT R_TmpRacEnclBlade.NodeID AS DeviceKey, R_TmpRacEnclBlade.dc_SystemName AS DeviceName, R_TmpRacEnclBlade.RackName,
               R_TmpBlade.EnclosureName, R_TmpRacEnclBlade.Name, R_TmpRacEnclBlade.SerialNumber, R_TmpRacEnclBlade.Model,
               R_TmpRacEnclBlade.Tag AS Type, R_TmpBlade.Slot_Number AS SlotNumber, R_TmpRacEnclBlade.SnapshotID
FROM  R_TmpRacEnclBlade LEFT OUTER JOIN
               R_TmpBlade ON R_TmpRacEnclBlade.SnapshotID = R_TmpBlade.SnapshotID AND
               R_TmpRacEnclBlade.Chassis_LUID = R_TmpBlade.Chassis_LUID AND R_TmpRacEnclBlade.NodeID = R_TmpBlade.NodeID
WHERE (R_TmpBlade.EnclosureName IS NOT NULL) AND (NOT (R_TmpBlade.EnclosureName = '')) OR
               (R_TmpRacEnclBlade.Name IS NOT NULL) AND (NOT (R_TmpRacEnclBlade.Name = '')) OR
               (R_TmpRacEnclBlade.Model IS NOT NULL) AND (NOT (R_TmpRacEnclBlade.Model = ''))
)
GO


CREATE VIEW R_Process
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_Process.Handle AS ID,
               CIM_Process.Name AS Name, CIM_Process.ExecutionState AS State,
               CIM_Process.Priority AS Priority, CIM_Process.SnapshotID
FROM  CIM_Process  LEFT OUTER JOIN
               devices ON CIM_Process.NodeID = devices.DeviceKey
)
GO


CREATE VIEW R_UnixOSDetails
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_OperatingSystem.Name AS OSName,
               CIM_OperatingSystem.Version AS OSVersion, CIM_OperatingSystem.dc_OperatingSystemCapability AS Capability,
               CIM_OperatingSystem.LastBootupTime AS SystemUptime, CIM_OperatingSystem.NumberOfUsers AS NumUsers,
               CIM_OperatingSystem.NumberOfProcesses AS NumProcesses, CIM_OperatingSystem.MaxNumberOfProcesses AS MaxProcesses,
               CIM_OperatingSystem.CurrentTimeZone AS TimeZone, CIM_OperatingSystem.SnapshotID
FROM  CIM_OperatingSystem LEFT OUTER JOIN
               devices ON CIM_OperatingSystem.NodeID = devices.DeviceKey
)
GO


CREATE VIEW R_UnixLogicalMemory
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_OperatingSystem.dc_SwapSpaceName AS SwapSpaceName,
               CIM_OperatingSystem.dc_SwapType AS SwapType,
               CIM_OperatingSystem.TotalSwapSpaceSize AS SwapSpaceSize,
               CIM_OperatingSystem.dc_SwapSpaceMinimumSize AS SwapSpaceMinSize,
               CIM_OperatingSystem.dc_SwapSpaceMaximumSize AS SwapSpaceMaxSize,
               CIM_OperatingSystem.dc_SwapSpaceReservedSize AS SwapSpaceReservedSize,
               CIM_OperatingSystem.SnapshotID
FROM  CIM_OperatingSystem LEFT OUTER JOIN
               devices ON CIM_OperatingSystem.NodeID = devices.DeviceKey
)
GO


CREATE VIEW R_UnixIODevices
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_LogicalDevice.OtherIdentifyingInfo AS DeviceType,
               CIM_LogicalDevice.Description AS DeviceDescription, CIM_LogicalDevice.Name AS DeviceIdentifier,
               CIM_LogicalDevice.Availability AS DeviceStatus, CIM_LogicalDevice.LastErrorCode AS DeviceErrors,
               CIM_LogicalDevice.DeviceID AS HardwarePath, CIM_LogicalDevice.dc_HardwareType AS HardwareType,
               CIM_LogicalDevice.Caption AS DeviceClass, CIM_LogicalDevice.dc_AssociatedDriver AS AssociatedDriver,
               CIM_LogicalDevice.SnapshotID
FROM  CIM_LogicalDevice LEFT OUTER JOIN
               devices ON CIM_LogicalDevice.NodeID = devices.DeviceKey
)
GO


CREATE VIEW R_UnixIPRoute
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_IPRoute.IPDestinationAddress AS RouteDestination,
               CIM_IPRoute.IPDestinationMask AS RouteMask, CIM_IPRoute.NextHop AS RouteGateway,
               CIM_IPRoute.SnapshotID
FROM  CIM_IPRoute LEFT OUTER JOIN
               devices ON CIM_IPRoute.NodeID = devices.DeviceKey
)
GO


CREATE VIEW R_HPUXFileSystem
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, HPUX_HFS.Name AS MountPointName,
               HPUX_HFS.Root AS MountSpecialDeviceName, HPUX_HFS.RemoteFileSystem_Name AS RemoteMountPointName,
               HPUX_HFS.FileSystemType AS FileSystemType, HPUX_HFS.ReadOnly AS FileSystemAccess,
               HPUX_HFS.Bootable AS FileSystemBootable, HPUX_HFS.TotalInodes AS TotalInodes, HPUX_HFS.FreeInodes AS FreeInodes,
               HPUX_HFS.FileSystemSize AS DataCapacity, HPUX_HFS.AvailableSpace AS FreeCapacity,
               HPUX_HFS.MinimumFreeSpace AS MinFreeSpace, HPUX_HFS.SnapshotID
FROM  HPUX_HFS LEFT OUTER JOIN
               devices ON HPUX_HFS.NodeID = devices.DeviceKey
)
GO


CREATE VIEW R_HPUXVolumeGroup
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, HPUX_VolumeGroup.Name AS VolumeGroupName,
               HPUX_VolumeGroup.AccessPermission AS AccessPermission, HPUX_VolumeGroup.Status AS Status,
               HPUX_VolumeGroup.PhysicalExtentSize AS ExtentSize, HPUX_VolumeGroup.Capacity AS Capacity,
               HPUX_VolumeGroup.Allocated AS Allocation, HPUX_VolumeGroup.FreeSpace AS FreeSpace,
               HPUX_VolumeGroup.MaxNumberOfPVs AS MaxNumPhysicalVol, HPUX_VolumeGroup.MaxPEsPerPV AS MaxNumPhysicalExtent,
               HPUX_VolumeGroup.NumberOfDefinedPVs AS NumDefinedPhysicalVol, HPUX_VolumeGroup.NumberOfActivePVs AS NumActivePhysicalVol,
               HPUX_VolumeGroup.MaxNumberOfLVs AS MaxNumLogicalVol, HPUX_VolumeGroup.SnapshotID
FROM  HPUX_VolumeGroup LEFT OUTER JOIN
               devices ON HPUX_VolumeGroup.NodeID = devices.DeviceKey
)
GO


CREATE VIEW R_HPUXLogicalVolume
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, HPUX_LogicalVolume.Name AS LogicalVolName,
               HPUX_LogicalVolume.Access_ AS AccessPermission, HPUX_LogicalVolume.Status AS Status,
               HPUX_LogicalVolume.LogicalExtentSize AS ExtentSize,
               DECODE( HPUX_LogicalVolume.Capacity, NULL, DECODE(HPUX_LogicalVolume.BlockSize,NULL,0,HPUX_LogicalVolume.BlockSize) * DECODE(HPUX_LogicalVolume.NumberOfBlocks,NULL,0,HPUX_LogicalVolume.NumberOfBlocks)) AS Capacity,
               HPUX_LogicalVolume.SchedulePolicy AS SchedulePolicy, HPUX_LogicalVolume.AllocationPolicy AS AllocationPolicy,
               HPUX_LogicalVolume.SnapshotID
FROM  HPUX_LogicalVolume LEFT OUTER JOIN
               devices ON HPUX_LogicalVolume.NodeID = devices.DeviceKey
)
GO


CREATE VIEW R_HPUXPhysicalVolume
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, HPUX_PhysicalVolume.Name AS PhysicalVolName,
               HPUX_PhysicalVolume.Status AS Status,
               HPUX_PhysicalVolume.PhysicalExtentSize AS ExtentSize,
               DECODE( HPUX_PhysicalVolume.Capacity, NULL, DECODE(HPUX_PhysicalVolume.BlockSize,NULL,0,HPUX_PhysicalVolume.BlockSize) * DECODE(HPUX_PhysicalVolume.NumberOfBlocks,NULL,0,HPUX_PhysicalVolume.NumberOfBlocks)) AS Capacity,
               HPUX_PhysicalVolume.Allocated AS AllocatedPhysicalExtent, HPUX_PhysicalVolume.Free AS FreePhysicalExtent,
               HPUX_PhysicalVolume.SnapshotID
FROM  HPUX_PhysicalVolume LEFT OUTER JOIN
               devices ON HPUX_PhysicalVolume.NodeID = devices.DeviceKey
)
GO


CREATE VIEW R_HPUXNetworkDetails
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, HPUX_DNSService.Name AS DomainName,
                      HPUX_DNSService.SearchList AS Search, HPUX_DNSService.Addresses AS ServerIPAddress,
                      HPUX_NISServerService.ServerType, HPUX_NISServerService.ServerWaitFlag,
                      HPUX_NTPService.ServerAddress, HPUX_DNSService.SnapshotID
FROM      HPUX_NTPService RIGHT OUTER JOIN
                      devices INNER JOIN
                      HPUX_DNSService ON devices.DeviceKey = HPUX_DNSService.NodeID LEFT OUTER JOIN
                      HPUX_NISServerService ON HPUX_DNSService.NodeID = HPUX_NISServerService.NodeID AND
                      HPUX_DNSService.SnapshotID = HPUX_NISServerService.SnapshotID ON
                      HPUX_NTPService.NodeID = HPUX_DNSService.NodeID AND
                      HPUX_NTPService.SnapshotID = HPUX_DNSService.SnapshotID
)
GO


CREATE VIEW R_HPUXKernelParam
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, HPUX_BaseKernelParameter.SettingID AS ParameterName,
               HPUX_BaseKernelParameter.CurrentValue AS ParameterValue, HPUX_BaseKernelParameter.SnapshotID
FROM  HPUX_BaseKernelParameter LEFT OUTER JOIN
               devices ON HPUX_BaseKernelParameter.NodeID = devices.DeviceKey
)
GO

CREATE VIEW R_HPUXSoftwareBundle
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, HPUX_Bundle.Name AS BundleName,
               HPUX_Bundle.Vendor AS VendorTag, HPUX_Bundle.Architecture AS Architecture,
               HPUX_Bundle.Version AS Revision, HPUX_Bundle.Caption AS Caption,
               HPUX_Bundle.ModificationTime AS ModificationTime, HPUX_Bundle.Size_ AS Size_,
               HPUX_Bundle.LayoutVersion AS LayoutVersion, HPUX_Bundle.OperatingSystemName AS OSName,
               HPUX_Bundle.OperatingSystemRelease AS OSRelease, HPUX_Bundle.IsPatch AS IsPatch,
               HPUX_Bundle.InstallSource AS InstallSource, HPUX_Bundle.InstallDate AS InstallDate,
               HPUX_Bundle.SnapshotID
FROM  HPUX_Bundle LEFT OUTER JOIN
               devices ON HPUX_Bundle.NodeID = devices.DeviceKey
)
GO


CREATE VIEW R_HPUXSoftwareProduct
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, HPUX_Product.IdentifyingNumber AS Specification,
               HPUX_Product.Name AS ProductName, HPUX_Product.Architecture AS Architecture,
               HPUX_Product.Version AS Revision, HPUX_Product.Vendor AS VendorTag,
               HPUX_Product.Caption AS Caption, HPUX_Product.ModificationTime AS ModificationTime,
               HPUX_Product.Size_ AS Size_, HPUX_Product.OperatingSystemName AS OSName,
               HPUX_Product.OperatingSystemRelease AS OSRelease, HPUX_Product.IsPatch AS IsPatch,
               HPUX_Product.InstallSource AS InstallSource, HPUX_Product.InstallDate AS InstallDate,
               HPUX_Product.SnapshotID
FROM  HPUX_Product LEFT OUTER JOIN
               devices ON HPUX_Product.NodeID = devices.DeviceKey
)
GO

CREATE VIEW R_lockdownStatus
AS
SELECT lockdownStatus.deviceKey,
            lockdownStatus.deviceName,
            lockdownStatus.LastScanName,
            lockdownStatus.LastScanDate,
            lockdownStatus.LastVulChk,
            lockdownStatus.Critical,
            lockdownStatus.Major,
            lockdownStatus.Minor,
            lockdownStatus.Warning,
            lockdownStatus.LPatchDate,
            lockdownStatus.LPatchApplied,
            lockdownStatus.PatchRqd,
            lockdownStatus.PatchMiss, -1 AS SnapShotID
FROM lockdownStatus INNER JOIN
            devices ON lockdownStatus.deviceKey = devices.DeviceKey
GO

CREATE VIEW R_CellularSysPartition
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, HP_NParPartition.PartitionName, IPAddress.IPAddress,  HP_NParPartition.dc_TotalCPU AS TotalCPUCore,
               HP_NParPartition.dc_InstalledCells AS InstalledCells, HP_NParPartition.dc_PoweredOnCells AS PoweredonCells,
                HP_NParPartition.dc_CoreCell AS CoreCell, HP_NParPartition.dc_CoreCellCabinet AS CoreCellCabinet,
               HP_NParPartition.r_dc_HasInterleaveMem AS HasInterleaveMemory, HP_NParPartition.SnapshotID
FROM  devices INNER JOIN
               HP_NParPartition ON devices.DeviceKey = HP_NParPartition.NodeID INNER JOIN
               IPAddress ON devices.DeviceKey = IPAddress.DeviceKey
)
GO

CREATE VIEW R_CellularSysParComplex
AS(
SELECT devices.DeviceKey,devices.Name AS DeviceName, HP_NParComplex.ComplexName, HP_NParComplex.dc_ComputeCabCount AS ComputeCabinets,
               HP_NParComplex.dc_IOXCabCount AS IOCabinets, HP_NParComplex.SnapshotID
FROM  HP_NParComplex LEFT OUTER JOIN
              devices ON HP_NParComplex.NodeID = devices.DeviceKey
)
GO

CREATE VIEW R_CellularSysParIOChassis
AS(
SELECT devices.DeviceKey,devices.Name AS DeviceName, HP_NParPartition.PartitionName,  HP_NParIOChassisSlot.CabinetID AS CabinetNumber,
               HP_NParIOChassisSlot.IOBayNumber, HP_NParIOChassisSlot.Number_ AS IOChassisNumber, HP_NParIOChassisSlot.SnapshotID
FROM  devices INNER JOIN
               HP_NParIOChassisSlot ON devices.DeviceKey =HP_NParIOChassisSlot.NodeID INNER JOIN
               HP_NParPartition ON HP_NParIOChassisSlot.NodeID = HP_NParPartition.NodeID
)
GO

CREATE TABLE vmmStatus (
    deviceKey int NOT NULL ,
    vmmStatus int NULL,
    CONSTRAINT PK_vmmStatus PRIMARY KEY
    (
        deviceKey
    )
)
GO

CREATE TABLE hpmxQuery (
    LUID number(19) NOT NULL,
    Name varchar (80) DEFAULT (' ') NOT NULL,
    QueryTypeInt int  DEFAULT (-1) NOT NULL,
    CONSTRAINT PK_hpmxQuery PRIMARY KEY
    (
        LUID
    )
)
GO


--add new Persistence layer beans

create table CIM_NetworkPort (
   networkPort_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   ElementName nvarchar2(255) null,
   Name nvarchar2(1024) null,
   SystemCreationClassName nvarchar2(256) null,
   SystemName nvarchar2(256) null,
   CreationClassName nvarchar2(256) null,
   DeviceID nvarchar2(64) null,
   Speed number(19) null,
   MaxSpeed number(19) null,
   UsageRestriction number(5,0) null,
   PortType number(5,0) null,
   OtherPortType nvarchar2(255) null,
   LinkTechnology number(5,0) null,
   OtherLinkTechnology nvarchar2(255) null,
   PermanentAddress nvarchar2(64) null,
   OtherNetworkPortType nvarchar2(255) null,
   PortNumber number(5,0) null,
   R_OperationalStatus nvarchar2(256) null,
   R_ParentName nvarchar2(256) null,
   R_PortType nvarchar2(256) null,
   constraint networkPort_PK primary key ( networkPort_LUID )
)
GO
create index cim_np_ak on cim_networkPort (NodeId, SnapshotId, deviceId, systemName)
GO

create table operationalStatus_NPvalues (
   OperationalStatusId number(19) not null,
   OperationalStatusValue number(5,0),
   OperationalStatusPos number(10,0) not null,
   constraint operationalStatus_NPVPK primary key (OperationalStatusId, OperationalStatusPos))
GO

create table SCSIProtoCont_SCSIProtoEnd (
   AvailableSAP number(19) not null,
   ManagedElement number(19) not null,
   constraint SCSProtoCont_SCSIProtoEndPK primary key (ManagedElement, AvailableSAP)
)
GO
create index spc_spe_rev on SCSIProtoCont_SCSIProtoEnd (AvailableSAP)
GO

create table SCSIProtoEnd_TCPProtoEnd (
   Dependent number(19) not null,
   Antecedent number(19) not null,
   constraint SCSIProtoEnd_TCPProtoEnd primary key (Antecedent, Dependent)
)
GO
create index spe_tpe_rev on SCSIProtoEnd_TCPProtoEnd (Dependent)
GO

create table CIM_Product (
   Product_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   ElementName nvarchar2(255),
   Name nvarchar2(256) not null,
   IdentifyingNumber nvarchar2(64) not null,
   Vendor nvarchar2(256) not null,
   Version nvarchar2(64) not null,
    constraint Product_PK primary key (Product_LUID)
)
GO
create index cim_product_ak on CIM_Product (NodeId,SnapshotId,name,identifyingNumber)
GO

create table CIM_SCSIProtocolEndpoint (
   SCSIProtocolEndpoint_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   Name nvarchar2(1024),
   SystemCreationClassName nvarchar2(256),
   SystemName nvarchar2(256),
   CreationClassName nvarchar2(256),
   ConnectionType number(5,0),
   ProtocolIFType number(5,0),
   Role number(5,0),
    constraint SCSIProtocolEndpoint_PK primary key (SCSIProtocolEndpoint_LUID)
)
GO
create index cim_scsi_protoend_ak on CIM_SCSIProtocolEndpoint (NodeId,SnapshotId,name,systemName)
GO

create table CIM_ChangerDevice (
   changerDevice_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   ElementName varchar2(255),
   SystemCreationClassName varchar2(256),
   SystemName varchar2(256),
   CreationClassName varchar2(256),
   DeviceID varchar2(64),
   Availability number(5,0),
   primary key (changerDevice_LUID)
)
GO
create index cim_changer_ak on CIM_ChangerDevice (NodeId,SnapshotId, deviceId, SystemName)
GO
create table operationalStatusCD_values (
   OperationalStatusId number(19) not null,
   OperationalStatusValue number(5,0),
   OperationalStatusPos number(10,0) not null,
   primary key (OperationalStatusId, OperationalStatusPos)
)
GO
create table ChangerDev_SoftwareIdent (
   dependent number(19) not null,
   antecedent number(19) not null,
   primary key (dependent, antecedent)
)
GO

create table CIM_iSCSISession (
   ISCSISession_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   InstanceID nvarchar2(255),
   SessionType number(5,0),
   TSIH number(10,0),
   EndPointName nvarchar2(255),
   CurrentConnections number(10,0),
   ErrorRecoveryLevel number(10,0),
    constraint ISCSISession_PK primary key (ISCSISession_LUID)
)
GO
create index cim_iscsisession_luid on CIM_iSCSISession (NodeId,SnapshotId,instanceId)
GO

create table SCSIProtoEnd_iSCSISession (
   Antecedent number(19) not null,
   Dependent number(19) not null,
   constraint SCSIProtoEnd_iSCSISessionPK primary key (Dependent, Antecedent)
)
GO
create index spe_iss_rev on SCSIProtoEnd_iSCSISession (Antecedent)
GO

create table SCSIProtoEnd_NetworkPort (
   Antecedent number(19) not null,
   Dependent number(19) not null,
   constraint SCSIProtoEnd_NetworkPortPK primary key (Dependent, Antecedent)
)
GO
create index spe_np_rev on SCSIProtoEnd_NetworkPort (Antecedent)
GO

create table classifications_values (
   ClassificationsId number(19) not null,
   ClassificationsValue number(5,0),
   ClassificationsPos number(10,0) not null,
   constraint classification_valuesPK primary key (ClassificationsId, ClassificationsPos)
)
GO

create table IPProtocolEnd_NetworkPort (
   Dependent number(19) not null,
   Antecedent number(19) not null,
   constraint IPProtocolEnd_NetworkPoPK primary key (Antecedent, Dependent)
)
GO
create index ippe_np_rev on IPProtocolEnd_NetworkPort (Dependent)
GO

create table CIM_SCSIProtocolController (
   SCSIProtocolController_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   ElementName nvarchar2(255),
   SystemCreationClassName nvarchar2(256) not null,
   SystemName nvarchar2(256) not null,
   CreationClassName nvarchar2(256) not null,
   DeviceID nvarchar2(64) not null,
   MaxUnitsControlled number(10,0),
    constraint SCSIProtocolController_PK primary key (SCSIProtocolController_LUID)
)
GO
create index cim_spk_ak on CIM_SCSIProtocolController (NodeId, SnapshotId, deviceId, systemName)
GO

create table CIM_Realizes (
   Antecedent number(19) not null,
   Dependent number(19) not null,
   constraint CIM_RealizesPK primary key (Antecedent, Dependent)
)
GO
create index cim_realizes_rev on CIM_Realizes (Dependent)
GO

create table ComputerSys_MediaAccessDev (
   GroupComponent number(19) not null,
   PartComponent number(19) not null,
   primary key (GroupComponent, PartComponent)
)
GO

create table ComputerSys_ChangerDevice (
   GroupComponent number(19) not null,
   PartComponent number(19) not null,
   primary key (GroupComponent, PartComponent)
)
GO

create table ComputerSys_SCSIProtoEndp (
   Antecedent number(19) not null,
   Dependent number(19) not null,
   constraint ComputerSys_SCSIProtoEnPK primary key (Dependent, Antecedent)
)
GO
create index cs_spe_rev on ComputerSys_SCSIProtoEndp (Antecedent)
GO

create table CIM_ElementCapabilities (
   Antecedent number(19) not null,
   Dependent number(19) not null,
   constraint CIM_ElementCapabilitiesPK primary key (Antecedent, Dependent)
)
GO
create index cim_elementCap_rev on CIM_ElementCapabilities (Dependent)
GO

create table CIM_StorageVolume (
   StorageVolume_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   DataRedundancy number(5,0),
   ElementName nvarchar2(255),
   NameFormat number(5,0),
   NoSinglePointOfFailure number(1,0),
   PackageRedundancy number(5,0),
   Name nvarchar2(1024),
   SystemCreationClassName nvarchar2(256) not null,
   SystemName nvarchar2(256) not null,
   CreationClassName nvarchar2(256) not null,
   DeviceID nvarchar2(64) not null,
   Availability number(5,0),
   BlockSize number(19),
   NumberOfBlocks number(19),
   ConsumableBlocks number(19),
   IsBasedOnUnderlyingRedundanc number(1,0),
   SequentialAccess number(1,0),
   R_OperationalStatus nvarchar2(256),
   R_ExtentStatus nvarchar2(256),
   R_RaidLevel nvarchar2(256),
    constraint StorageVolume_PK primary key (StorageVolume_LUID)
)
GO
create index sv_ak on cim_storageVolume (NodeId, SnapshotId, deviceId, systemName)
GO
create table CIM_ElementSettingData (
   Element number(19) not null,
   Setting number(19) not null,
   primary key (Element, Setting)
)
GO
create index element_setting_rev on CIM_ElementSettingData (Setting, Element)
GO
create table CIM_StorageSetting (
   storageSetting_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   ElementName varchar2(255),
   InstanceID varchar2(255) not null,
   constraint StorageSetting_PK primary key (storageSetting_LUID)
)
GO
create index storage_setting_ak on CIM_StorageSetting (NodeId, SnapshotID, InstanceID)
GO
create table CIM_LogicalPortGroup (
   LogicalPortGroup_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   InstanceID nvarchar2(255) not null,
   Name nvarchar2(256),
   NameFormat nvarchar2(64),
   ElementName nvarchar2(255),
    constraint LogicalPortGroup_PK primary key (LogicalPortGroup_LUID)
)
GO
create index cim_lpg_ak on CIM_LogicalPortGroup (NodeId,SnapshotId)
GO

create table CIM_ComponentCS (
   GroupComponent number(19) not null,
   PartComponent number(19) not null,
   constraint CIM_ComponentCSPK primary key (GroupComponent, PartComponent)
)
GO
create index cim_componentCS_rev on CIM_ComponentCS (PartComponent)
GO

create table CIM_TCPProtocolEndpoint (
   TCPProtocolEndpoint_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   Name nvarchar2(1024),
   SystemCreationClassName nvarchar2(256),
   SystemName nvarchar2(256),
   CreationClassName nvarchar2(256),
   ProtocolIFType number(5,0),
   PortNumber number(10,0),
    constraint TCPProtocolEndpoint_PK primary key (TCPProtocolEndpoint_LUID)
)
GO
create index cim_tcp_end_ak on CIM_TCPProtocolEndpoint (NodeId,SnapshotId,name,systemName)
GO

create table CIM_IPProtocolEndpoint (
   IPProtocolEndpoint_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   Name nvarchar2(1024) not null,
   SystemCreationClassName nvarchar2(256),
   SystemName nvarchar2(256),
   CreationClassName nvarchar2(256),
   IPv4Address nvarchar2(255),
   IPv6Address nvarchar2(255),
    constraint IPProtocolEndpoint_PK primary key (IPProtocolEndpoint_LUID)
)
GO
create index cim_ipproto_end_ak on CIM_IPProtocolEndpoint (NodeId,SnapshotId,name,systemName)
GO

create table SVAllocatedFromStoragePool (
   SVAllocFromStoragePool_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   Antecedent number(19) not null,
   Dependent number(19) not null,
   SpaceConsumed number(19),
    constraint SVAllocFromStoragePool_PK primary key (SVAllocFromStoragePool_LUID)
)
GO
CREATE INDEX svafsp_association ON SVAllocatedFromStoragePool(dependent, antecedent)
GO
create index svafsp_assoc_rev ON SVAllocatedFromStoragePool(antecedent)
GO
create index svafsp_ak ON SVAllocatedFromStoragePool(NodeId, SnapshotId)
GO

create table authenticationMethods_values (
   AuthenticationMethodsId number(19) not null,
   AuthenticationMethodsValue number(5,0),
   AuthenticationMethodsPos number(10,0) not null,
   constraint authenticationMethods_valPK primary key (AuthenticationMethodsId, AuthenticationMethodsPos)
)
GO

create table CIM_ProtocolControllerForUnit (
   ProtocolControllerForUnit_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   DeviceNumber nvarchar2(255),
   Antecedent number(19),
   Dependent number(19),
    constraint ProtocolControllerForUnit_PK primary key (ProtocolControllerForUnit_LUID)
)
GO
CREATE INDEX pcfu_association ON CIM_ProtocolControllerForUnit(dependent)
GO
create index pcfu_rev_assoc ON CIM_ProtocolControllerForUnit (antecedent)
GO
create index pcfu_ak on CIM_ProtocolControllerForUnit(NodeId, SnapshotId)
GO

create table networkAddresses_values (
   NetworkAddressesId number(19) not null,
   NetworkAddressesValue nvarchar2(64),
   NetworkAddressesPos number(10,0) not null,
   constraint networkAddresses_valuesPK primary key (NetworkAddressesId, NetworkAddressesPos)
)
GO

create table SPAllocatedFromStoragePool (
   SPAllocFromStoragePool_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   Antecedent number(19),
   Dependent number(19),
   SpaceConsumed number(19),
    constraint SPAllocFromStoragePool_PK primary key (SPAllocFromStoragePool_LUID)
)
GO
CREATE INDEX spafsp_association ON SPAllocatedFromStoragePool(dependent)
GO
CREATE INDEX spafsp_assoc_rev ON SPAllocatedFromStoragePool (antecedent)
GO
create index spafsp_ak ON SPAllocatedFromStoragePool (NodeId, SnapshotId)
GO

create table CIM_NetworkPipeComposition (
   Antecedent number(19) not null,
   Dependent number(19) not null,
   constraint CIM_NetworkPipeCompositionPK primary key (Antecedent, Dependent)
)
GO
create index cim_networkPipeComposition_rev ON CIM_NetworkPipeComposition (dependent)
GO

create table CIM_PortController (
   PortController_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   ElementName nvarchar2(255),
   SystemCreationClassName nvarchar2(256) not null,
   SystemName nvarchar2(256) not null,
   CreationClassName nvarchar2(256) not null,
   DeviceID nvarchar2(64) not null,
   ProtocolSupported number(5,0),
   R_OperationalStatus nvarchar2(256),
   R_PortCount number(10,0),
   R_PortUtilized number(10,0),
    constraint PortController_PK primary key (PortController_LUID)
)
GO
create index cim_portController_ak on CIM_PortController (NodeId,SnapshotId,deviceId,systemName)
GO

create table extentStatus_values (
   ExtentStatusId number(19) not null,
   ExtentStatusValue number(5,0),
   ExtentStatusPos number(10,0) not null,
   constraint extentStatus_valuesPK primary key (ExtentStatusId, ExtentStatusPos)
)
GO

create table ComputerSys_HAP (
   Antecedent number(19) not null,
   Dependent number(19) not null,
   constraint ComputerSys_HAPPK primary key (Antecedent, Dependent)
)
GO
create index computerSys_HAP_rev on ComputerSys_HAP (dependent)
GO

create table operationalStatus_PCvalues (
   OperationalStatusId number(19) not null,
   OperationalStatusValue number(5,0),
   OperationalStatusPos number(10,0) not null,
   constraint operationalStatus_PCvalPK primary key (OperationalStatusId, OperationalStatusPos)
)
GO

create table ComputerSys_SAP (
   AvailableSAP number(19) not null,
   ManagedElement number(19) not null,
   constraint ComputerSys_SAPPK primary key (AvailableSAP, ManagedElement)
)
GO
create index computerSys_SAP_rev on ComputerSys_SAP (ManagedElement)
GO

create table CIM_ProtocolControllerForPort (
   Dependent number(19) not null,
   Antecedent number(19) not null,
   constraint CIM_ProtocolControllerForPoPK primary key (Antecedent, Dependent)
)
GO
create index cim_pcfp_rev on cim_protocolControllerForPort (dependent)
GO

create table ComputerSys_StorageVol (
   GroupComponent number(19) not null,
   PartComponent number(19) not null,
   constraint ComputerSys_StorageVolPK primary key (GroupComponent, PartComponent)
)
GO
create index ComputerSys_StorageVol_rev on ComputerSys_StorageVol (PartComponent)
GO

create table CIM_ControlledBy (
   Antecedent number(19) not null,
   Dependent number(19) not null,
   constraint CIM_ControlledByPK primary key (Antecedent, Dependent)
)
GO
create index cim_controlledBy_rev on CIM_ControlledBy (Dependent)
GO

create table iSCSIConn_TCPProtoEnd (
   Antecedent number(19) not null,
   Dependent number(19) not null,
   constraint iSCSIConn_TCPProtoEndPK primary key (Dependent, Antecedent)
)
GO
create index iSCSIConn_TCPProtoEnd_rev on iSCSIConn_TCPProtoEnd (Antecedent)
GO

create table PortController_SoftwareIdent (
   System number(19) not null,
   InstalledSoftware number(19) not null,
   constraint PortController_SoftwareIdent primary key (System, InstalledSoftware)
)
GO
create index CIM_pc_si_rev on PortController_SoftwareIdent (InstalledSoftware)
GO

create table PhysicalPackage_Product (
   PartComponent number(19) not null,
   GroupComponent number(19) not null,
   constraint PhysicalPackage_ProductPK primary key (GroupComponent, PartComponent)
)
GO
create index pp_p_rev on PhysicalPackage_Product (PartComponent)
GO

create table CIM_MemberOfCollection (
   Collection number(19) not null,
   Member number(19) not null,
   constraint CIM_MemberOfCollectionPK primary key (Member, Collection)
)
GO
create index CIM_MemberOfCollection_rev on CIM_MemberOfCollection (Collection)
GO

create table CIM_ProtoControlAccessesUnit (
   ProtoControlAccessUnit_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   DeviceNumber nvarchar2(255),
   Antecedent number(19),
   Dependent number(19),
   Name nvarchar2(1024),
    constraint ProtoControlAccessUnit_PK primary key (ProtoControlAccessUnit_LUID)
)
GO
CREATE INDEX pcau_association ON CIM_ProtoControlAccessesUnit(Dependent)
GO
create index  pcau_rev_assoc on CIM_ProtoControlAccessesUnit (Antecedent)
GO
create index pcau_ak on CIM_ProtoControlAccessesUnit(NodeId,SnapshotId)
GO

create table ComputerSys_LogicalPortGroup (
   Antecedent number(19) not null,
   Dependent number(19) not null,
   constraint ComputerSys_LogicalPortGrpPK primary key (Antecedent, Dependent)
)
GO
create index cs_lpg_rev on ComputerSys_LogicalPortGroup (Dependent)
GO

create table CIM_StoragePool (
   StoragePool_LUID number(19) not null,
   NodeId number(19) not null,
   SnapshotId number(19) not null,
   ElementName nvarchar2(255),
   InstanceID nvarchar2(255) not null,
   PoolID nvarchar2(256),
   Primordial number(1,0),
   TotalManagedSpace number(19),
   RemainingManagedSpace number(19),
    constraint StoragePool_PK primary key (StoragePool_LUID)
)
GO
create index cim_sp_ak on cim_storagepool (NodeId, SnapshotId, instanceId)
GO

create table SCSIProtocolCont_SoftwareId (
   System number(19) not null,
   InstalledSoftware number(19) not null,
    constraint SCSIProtocolCont_SoftwareIDPK primary key (System, InstalledSoftware)
)
GO
create index spc_si_rev on SCSIProtocolCont_SoftwareId (InstalledSoftware)
GO

create table operationalStatus_SVvalues (
   OperationalStatusId number(19) not null,
   OperationalStatusValue number(5,0),
   OperationalStatusPos number(10,0) not null,
   constraint operationalStatus_SVvalPK primary key (OperationalStatusId, OperationalStatusPos)
)
GO

create table CIM_RemoteServiceAccessPoint (
   RemoteServiceAccessPoint_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   ElementName nvarchar2(255),
   SystemCreationClassName nvarchar2(256) not null,
   SystemName nvarchar2(256) not null,
   AccessInfo nvarchar2(255),
   CreationClassName nvarchar2(256) not null,
   Name nvarchar2(1024) not null,
    constraint RemoteServiceAccessPoint_PK primary key (RemoteServiceAccessPoint_LUID)
)
GO
create index rsap_ak on CIM_RemoteServiceAccessPoint (NodeId,SnapshotId,name,systemName)
GO

create table ComputerSys_NetworkPort (
   GroupComponent number(19) not null,
   PartComponent number(19) not null,
   constraint ComputerSys_NetworkPortPK primary key (GroupComponent, PartComponent)
)
GO
create index cs_np_rev on ComputerSys_NetworkPort (PartComponent)
GO

create table CIM_HostedStoragePool (
   GroupComponent number(19) not null,
   PartComponent number(19) not null,
   constraint CIM_HostedStoragePoolPK primary key (GroupComponent, PartComponent)
)
GO
create index cim_hsp_rev on CIM_HostedStoragePool (PartComponent)
GO

create table CIM_PhysicalPackage (
   PhysicalPackage_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   ElementName nvarchar2(255),
   Name nvarchar2(1024),
   Tag nvarchar2(256) not null,
   CreationClassName nvarchar2(256) not null,
   Manufacturer nvarchar2(256),
   Model nvarchar2(256),
   PartNumber nvarchar2(256),
    constraint PhysicalPackage_PK primary key (PhysicalPackage_LUID)
)
GO
create index cim_pp_ak on CIM_PhysicalPackage (NodeId,SnapshotId,tag,creationClassName)
GO

create table CIM_iSCSIConnection (
   ISCSIConnection_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   ElementName nvarchar2(255),
   InstanceID nvarchar2(255),
   ConnectionID number(10,0),
   HeaderDigestMethod number(5,0),
   OtherHeaderDigestMethod nvarchar2(255),
   DataDigestMethod number(5,0),
   OtherDataDigestMethod nvarchar2(255),
   ActiveiSCSIVersion number(1,0),
    constraint ISCSIConnection_PK primary key (ISCSIConnection_LUID)
)
GO
create index cim_isc_ak on CIM_iSCSIConnection (NodeId,SnapshotId,instanceId)
GO

create table ComputerSys_SCSIProtoCont (
   GroupComponent number(19) not null,
   PartComponent number(19) not null,
   constraint ComputerSys_SCSIProtoContPK primary key (GroupComponent, PartComponent)
)
GO
create index cs_spc_rev on ComputerSys_SCSIProtoCont (PartComponent)
GO

create table CIM_SoftwareIdentity (
   SoftwareIdentity_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   InstanceID nvarchar2(255) not null,
   VersionString nvarchar2(255),
   Manufacturer nvarchar2(255),
   Description nvarchar2(512),
   MajorVersion number(5,0),
   MinorVersion number(5,0),
   RevisionNumber number(5,0),
   BuildNumber number(5,0),
   DeviceSW_Purpose number(5,0),
   TargetType nvarchar2(256),
   TargetOperatingSystem number(5,0),
   InstallDate nvarchar2(256),
   swd_VersionWeight number(10,0),
   dc_OtherVersionInfo nvarchar2(64),
   SoftwareElementState number(5,0),
   Device_SW_PurposeDescription nvarchar2(512),
   R_Type nvarchar2(64),
   R_Date nvarchar2(256),
   R_Status nvarchar2(256),
    constraint SoftwareIdentity_PK primary key (SoftwareIdentity_LUID)
)
GO
create index cim_softwareId_ak on CIM_SoftwareIdentity (NodeId,SnapshotId,instanceId)
GO

create table CIM_iSCSICapabilities (
   ISCSICapabilities_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   ElementName nvarchar2(255),
   InstanceID nvarchar2(255),
   MinimumSpecificationVersionS smallint,
   MaximumSpecificationVersionS smallint,
    constraint ISCSICapabilities_PK primary key (ISCSICapabilities_LUID)
)
GO
create index cim_iscap_ak on CIM_iSCSICapabilities (NodeId,SnapshotId,instanceId)
GO

create table ComputerSys_PortController (
   GroupComponent number(19) not null,
   PartComponent number(19) not null,
   constraint ComputerSys_PortControllerPK primary key (GroupComponent, PartComponent)
)
GO
create index cs_pc_rev on ComputerSys_PortController (PartComponent)
GO

create table TCPProtoEnd_IPProtoEnd (
   Dependent number(19) not null,
   Antecedent number(19) not null,
   constraint TCPProtoEnd_IPProtoEndPK primary key (Antecedent, Dependent)
)
GO
create index tcppe_ippe_rev on TCPProtoEnd_IPProtoEnd (Dependent)
GO

create table CIM_ComputerSystemPackage (
   Dependent number(19) not null,
   Antecedent number(19) not null,
   constraint CIM_ComputerSystemPacakgePK primary key (Antecedent, Dependent)
)
GO
create index cim_csp_rev on CIM_ComputerSystemPackage(dependent)
GO

create table dedicated_values (
   DedicatedId number(19) not null,
   DedicatedValue number(5,0),
   DedicatedPos number(10,0) not null,
   constraint dedicated_valuesPK primary key (DedicatedId, DedicatedPos)
)
GO

create table ComputerSys_SoftwareIdent (
   System number(19) not null,
   InstalledSoftware number(19) not null,
   constraint ComputerSys_SoftwareIdPK primary key (System, InstalledSoftware)
)
GO
create index cs_si_rev on ComputerSys_SoftwareIdent (InstalledSoftware)
GO

create table operationalStatus_CSvalues (
   OperationalStatusId number(19) not null,
   OperationalStatusValue number(5,0),
   OperationalStatusPos number(10,0) not null,
   constraint operationalStatus_CSvalPK primary key (OperationalStatusId, OperationalStatusPos)
)
GO

create table PlugInInfo (
   PlugInInfoID number(19) not null,
   Name nvarchar2(256) not null,
   PackageName nvarchar2(1024) not null,
   ClassIdentifier number(10,0) not null,
   ClassIdString nvarchar2(255) not null,
   constraint plugInInfoPK primary key (PlugInInfoID))
GO

create table CIM_ProtocolEndpoint (
   protocolEndpoint_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   Name nvarchar2(1024),
   SystemCreationClassName nvarchar2(256),
   SystemName nvarchar2(256),
   CreationClassName nvarchar2(256),
   ProtocolIFType number(5,0),
   constraint protocolEndpoint_PK primary key (protocolEndpoint_LUID))
GO
create index cim_pe_luid on CIM_ProtocolEndpoint (NodeId,SnapshotId,name,systemName)
GO

create table CIM_ActiveConnection (
   Antecedent number(19) not null,
   Dependent number(19) not null,
   constraint activeConnection_PK primary key (Antecedent, Dependent))
GO
create index cim_activeCon_ak on CIM_ActiveConnection (dependent)
GO

create table CIM_DeviceSAPImplementation (
   deviceSAPImplementation_LUID number(19) not null,
   NodeID number(19) not null,
   SnapshotID number(19) not null,
   Antecedent number(19),
   Dependent number(19),
   dc_PermanentAddress nvarchar2(256),
   constraint deviceSAPImpl_PK primary key (deviceSAPImplementation_LUID))
GO
create index cim_dsi_ak on CIM_DeviceSAPImplementation (NodeId,SnapshotId)
GO
create index cim_dsi_assoc on CIM_DeviceSAPImplementation (antecedent,dependent)
GO
create index cim_dsi_assoc_rev on CIM_DeviceSAPImplementation (dependent)
GO

-- add CIM views


create view CIM_SystemDevice
AS(
select GroupComponent, PartComponent from ComputerSys_SCSIProtoCont
UNION ALL
select GroupComponent, PartComponent from ComputerSys_StorageVol
UNION ALL
select GroupComponent, PartComponent from ComputerSys_PortController
UNION ALL
select GroupComponent, PartComponent from ComputerSys_NetworkPort
UNION ALL
select GroupComponent, PartComponent from ComputerSys_ChangerDevice
UNION ALL
select GroupComponent, PartComponent from ComputerSys_MediaAccessDev
)
GO

create view CIM_InstalledSoftwareIdentity
AS(
select System, InstalledSoftware from ComputerSys_SoftwareIdent
UNION ALL
select System, InstalledSoftware from SCSIProtocolCont_SoftwareID
UNION ALL
select System, InstalledSoftware from PortController_SoftwareIdent
)
GO

create view CIM_ElementSoftwareIdentity
AS(
select antecedent, dependent from MediaAccessDev_SoftwareIdent
UNION ALL
select antecedent, dependent from ChangerDev_SoftwareIdent
)
GO

create view CIM_SAPAvailableForElement
AS(
select AvailableSAP, ManagedElement from SCSIProtoCont_SCSIProtoEnd
UNION ALL
select AvailableSAP, ManagedElement from ComputerSys_SAP
)
GO

create view CIM_HostedAccessPoint
AS(
select Antecedent, Dependent from ComputerSys_HAP
UNION ALL
select Antecedent, Dependent from ComputerSys_SCSIProtoEndp
)
GO

create view CIM_PortImplementsEndpoint
AS(
select Antecedent, Dependent from IPProtocolEnd_NetworkPort
UNION ALL
select Antecedent, Dependent from SCSIProtoEnd_NetworkPort
)
GO

create view CIM_HostedCollection
AS(
select Antecedent, Dependent from ComputerSys_LogicalPortGroup
)
GO

create view CIM_BindsTo
AS(
select Antecedent, Dependent from TCPProtoEnd_IPProtoEnd
UNION ALL
select Antecedent, Dependent from SCSIProtoEnd_TCPProtoEnd
)
GO

create view CIM_EndpointOfNetworkPipe
AS(
select Antecedent, Dependent from SCSIProtoEnd_iSCSISession
UNION ALL
select Antecedent, Dependent from iSCSIConn_TCPProtoEnd
)
GO

create view CIM_ProductPhysicalComponent
AS(
select GroupComponent, PartComponent from PhysicalPackage_Product
)
GO

create view CIM_AllocatedFromStoragePool
AS(
select SVAllocFromStoragePool_LUID AS AllocatedFromStoragePool_LUID, NodeID, SnapshotID, Antecedent, Dependent, SpaceConsumed from SVAllocatedFromStoragePool
UNION ALL
select SPAllocFromStoragePool_LUID AS AllocatedFromStoragePool_LUID, NodeID, SnapshotID, Antecedent, Dependent, SpaceConsumed from SPAllocatedFromStoragePool
)
GO



create table hpmxMgmtPath (
    LUID         number(19) NOT NULL,
    NodeLUID     number(19) NOT NULL,
    Version      varchar(32),
    ManagingType int NOT NULL
    )
GO

create table hpmxMgmtAgent (
    LUID number(19) NOT NULL,
    MaoType     varchar(64),
    PortNumber  int,
    IPAddress   char(16),
    Protocol    varchar(64)
      )
GO

create table hpmxMgmtRoute (
    LUID number(19)    NOT NULL,
    MaoLUID number(19) NOT NULL
      )
GO

create table  hpmxCimomMAO (
    LUID number(19)  NOT NULL,
    InteropNameSpace nvarchar2(256)
    )
GO


create table  hpmxCimomMRO (
    LUID number(19) NOT NULL,
    NameSpace nvarchar2(256),
    CimCSPath nvarchar2(256)
    )
GO

create table hpmxMpoProfile (
    MpoLUID      number(19) NOT NULL,
    ProfileName  nvarchar2(64) NULL
)
GO

create table hpmxMpoFuncProfile (
    MpoLUID          number(19) NOT NULL,
    FuncProfileName  nvarchar2(64) NULL
)
GO

CREATE TABLE categoryGroup (
    LUID number(19) NULL ,
    Name nvarchar2(255),
    DisplayFlag int NOT NULL ,
    EditFlag int NOT NULL ,
    CreatorId int NOT NULL ,
    Plugin int ,
    DisplayOrder int NOT NULL ,
    DisplayName nvarchar2(255),
    DisplayLocale nvarchar2(255),
    Privilege int NOT NULL
)
GO

CREATE TABLE hpmxCategory (
    LUID number(19) NOT NULL ,
    CategoryId int NOT NULL ,
    Name nvarchar2(255),
    Plugin int ,
    DisplayFlag int NOT NULL ,
    QueryType int NOT NULL ,
    EditFlag int ,
    DisplayOrder int NOT NULL ,
    DisplayName nvarchar2(255) NOT NULL ,
    DisplayLocale nvarchar2(50) NOT NULL ,
    DbViewName nvarchar2(50) NOT NULL ,
    SourceType int NOT NULL ,
    Source long ,
    SourceHandler char (256) ,
    CreatorId int ,
    Privilege int NOT NULL ,
    GroupLUID number(19) NOT NULL
)
GO

CREATE TABLE hpmxItem (
    LUID number(19) NOT NULL ,
    ItemId int NOT NULL ,
    Name nvarchar2(255) NOT NULL ,
    DisplayFlag int NOT NULL ,
    DisplayName nvarchar2(255) ,
    DisplayLocale nvarchar2(50) ,
    DbViewName nvarchar2(50) NOT NULL ,
    DbViewColName nvarchar2(50) NOT NULL ,
    OperationList long,
    DisplayOrder int ,
    Privilege int NOT NULL ,
    CategoryLUID number(19) NOT NULL
)
GO

CREATE TABLE hpmxReport (
    LUID number(19) NOT NULL ,
    ReportId int NOT NULL ,
    Name nvarchar2(255),
    Plugin int ,
    DisplayFlag int NOT NULL ,
    CreatorId int NOT NULL ,
    EditFlag int NOT NULL ,
    DisplayOrder int NOT NULL ,
    DisplayName nvarchar2(255) ,
    DisplayLocale nvarchar2(50)  ,
    QueryType int ,
    QueryId int ,
    QueryName nvarchar2(50)  ,
    ItemList long NOT NULL ,
    ViewOption int NOT NULL ,
    ViewFormat int NOT NULL ,
    Privilege int NOT NULL ,
    GroupLUID number(19) NOT NULL
)
GO

CREATE TABLE reportGroup (
    LUID number(19) NOT NULL ,
    Name nvarchar2(255) NOT NULL ,
    DisplayFlag int NOT NULL ,
    EditFlag int NOT NULL ,
    CreatorId int NOT NULL ,
    Plugin int ,
    DisplayOrder int NOT NULL ,
    DisplayName nvarchar2(255) ,
    DisplayLocale nvarchar2(50),
    Privilege int NOT NULL
)
GO

--- UPGRADE ISSUE with CIM_OperatingSystem.maxNumberOfProcesses too large.
update CIM_OperatingSystem set maxNumberOfProcesses = -1 where maxNumberOfProcesses > 2147483648
GO

---- ----------------------------------------------------------------------------------------
----  Create Storage Views
---- ----------------------------------------------------------------------------------------

CREATE VIEW R_StorageDeviceInventory
AS
SELECT	devices.DeviceKey, devices.Name AS DeviceName,
    CIM_ComputerSystem.ElementName AS ControllerName,
    CIM_ComputerSystem.Name AS WorldWideName, CIM_Product.Vendor,
    CIM_Product.Name AS Model, CIM_Product.Version AS ProductRevision,
    VersionString AS FirmwareVersion,
    CIM_Product.IdentifyingNumber AS SerialNumber,
    CIM_ComputerSystem.R_OperationalStatus AS Status,
    CIM_ComputerSystem.R_PortCount AS PortCount,
    CIM_ComputerSystem.R_PortUtilized AS PortUtilized,
    CIM_ComputerSystem.SnapshotID AS SnapshotID
FROM devices LEFT OUTER JOIN
    CIM_ComputerSystem  ON
    devices.deviceKey = cim_computerSystem.nodeID
    LEFT OUTER JOIN
    ((select  distinct versionString, groupComponent  from CIM_ComponentCS
        LEFT OUTER  JOIN
        computerSys_SoftwareIdent  ON
        system = partComponent   JOIN
        CIM_SoftwareIdentity  ON
        InstalledSoftware = softwareIdentity_LUID)
     UNION
    (select  VersionString ,ComputerSys_SoftwareIdent.System
        from CIM_SoftwareIdentity  RIGHT OUTER JOIN
        ComputerSys_softwareIdent  ON
        InstalledSoftware = softwareIdentity_LUID  )
    ) FirmwareInfo
    ON FirmwareInfo.groupComponent = computerSystem_LUID LEFT OUTER JOIN
    (select distinct CIM_ComputerSystemPackage.dependent,
        CIM_Product.Version, CIM_Product.Name, CIM_Product.Vendor,
        CIM_Product.IdentifyingNumber
    from CIM_ComputerSystemPackage
        LEFT OUTER JOIN CIM_PhysicalPackage
        ON physicalPackage_LUID = CIM_ComputerSystemPackage.antecedent
        LEFT OUTER JOIN PhysicalPackage_Product
        ON PhysicalPackage_Product.partComponent = CIM_PhysicalPackage.physicalPackage_LUID
        LEFT OUTER JOIN CIM_Product
        ON CIM_Product.product_LUID = PhysicalPackage_Product.groupComponent
    )  CIM_Product
    ON CIM_Product.dependent = computerSystem_LUID
WHERE CIM_ComputerSystem.SnapshotID IS NOT NULL
    and computerSystem_LUID not in
    (select partComponent from CIM_ComponentCS )
GO

CREATE VIEW R_StorageDeviceControllers
AS
SELECT  devices.DeviceKey, devices.Name AS DeviceName,
        CIM_ComputerSystem.ElementName AS ControllerName,
        CIM_ComputerSystem.Name AS WorldWideName, CIM_Product.Vendor,
        CIM_Product.Name AS Model, CIM_Product.Version AS ProductRevision,
        CIM_SoftwareIdentity.VersionString AS FirmwareVersion,
        CIM_Product.IdentifyingNumber AS SerialNumber,
        CIM_ComputerSystem.R_OperationalStatus AS Status,
        CIM_ComputerSystem.R_PortCount AS PortCount,
        CIM_ComputerSystem.R_PortUtilized AS PortUtilized,
        CIM_ComputerSystem.SnapshotID AS SnapshotID
FROM    devices LEFT OUTER JOIN
	CIM_ComputerSystem ON CIM_ComputerSystem.nodeID = deviceKey LEFT OUTER JOIN
	(select distinct CIM_ComputerSystemPackage.dependent, CIM_Product.Version,
	CIM_Product.Name, CIM_Product.Vendor, CIM_Product.IdentifyingNumber from
	CIM_ComputerSystemPackage  LEFT OUTER JOIN
	CIM_PhysicalPackage ON physicalPackage_LUID = CIM_ComputerSystemPackage.antecedent
	LEFT OUTER JOIN PhysicalPackage_Product ON
	PhysicalPackage_Product.partComponent = CIM_PhysicalPackage.physicalPackage_LUID
	LEFT OUTER JOIN CIM_Product
	ON CIM_Product.product_LUID = PhysicalPackage_Product.groupComponent
	) CIM_Product
	ON CIM_Product.dependent = CIM_ComputerSystem.computerSystem_LUID LEFT OUTER JOIN
	(select ComputerSys_SoftwareIdent.System, VersionString from
	CIM_SoftwareIdentity RIGHT OUTER JOIN
	ComputerSys_softwareIdent ON InstalledSoftware = softwareIdentity_LUID  )
	CIM_SoftwareIdentity ON System = computerSystem_LUID
	WHERE CIM_ComputerSystem.snapshotID IS NOT NULL
	AND computerSystem_LUID in ( select partComponent from CIM_ComponentCS )
GO

CREATE VIEW R_StorageHostBusAdapters
AS
SELECT  devices.DeviceKey, devices.Name AS DeviceName, PortInfo.ElementName AS HBAName
   ,PortInfo.DeviceID AS WorldWideName, CIM_Product.Vendor, CIM_Product.Name AS Model,
   PortInfo.r_OperationalStatus AS Status, CIM_Product.Version AS ProductRevision,
   DECODE(DriverSoftware.classificationsValue,2,DriverSoftware.VersionString,NULL) AS DriverVersion,
   DECODE(DriverSoftware.classificationsValue,6,DriverSoftware.VersionString,NULL) AS FirmwareVersion,
   DECODE(DriverSoftware.classificationsValue,8,DriverSoftware.VersionString,NULL) AS FCodeBIOSVersion,
   CIM_Product.IdentifyingNumber AS SerialNumber,
   PortInfo.R_PortCount AS PortCount, PortInfo.R_PortUtilized AS PortUtilized, PortInfo.SnapshotID
FROM devices LEFT OUTER JOIN CIM_ComputerSystem
   ON CIM_ComputerSystem.nodeID = deviceKey LEFT OUTER JOIN
   (select ComputerSys_PortController.groupComponent,
      ComputerSys_PortController.partComponent,
      CIM_PortController.* from
      ComputerSys_PortController
      LEFT OUTER JOIN CIM_PortController ON portController_LUID =
      ComputerSys_PortController.partComponent ) PortInfo
   ON groupComponent = computerSystem_LUID LEFT OUTER JOIN
   CIM_InstalledSoftwareIdentity ON
   PortInfo.partComponent = CIM_InstalledSoftwareIdentity.system
   LEFT OUTER JOIN
   (SELECT CIM_SoftwareIdentity.SoftwareIdentity_LUID,
      CIM_SoftwareIdentity.NodeID, CIM_SoftwareIdentity.SnapshotID,
      CIM_SoftwareIdentity.InstanceID, CIM_SoftwareIdentity.VersionString,
      CIM_SoftwareIdentity.Manufacturer, classifications_values.classificationsValue
      FROM classifications_values
      RIGHT OUTER JOIN CIM_SoftwareIdentity
      ON classifications_values.ClassificationsId =
      CIM_SoftwareIdentity.SoftwareIdentity_LUID WHERE
      (classifications_values.ClassificationsValue = 2) OR
      (classifications_values.ClassificationsValue = 6) OR
      (classifications_values.ClassificationsValue = 8)
      AND softwareIdentity_LUID is NOT NULL)  DriverSoftware ON
   DriverSoftware.SoftwareIdentity_LUID =
   CIM_InstalledSoftwareIdentity.installedSoftware
   LEFT OUTER JOIN
   (select distinct CIM_Realizes.antecedent,
      CIM_Product.Version, CIM_Product.Name,
      CIM_Product.Vendor, CIM_Product.IdentifyingNumber
      from  CIM_Realizes LEFT OUTER JOIN
      CIM_PhysicalPackage ON
      physicalPackage_LUID = CIM_Realizes.dependent
      LEFT OUTER JOIN PhysicalPackage_Product ON
      PhysicalPackage_Product.partComponent =
      CIM_PhysicalPackage.physicalPackage_LUID LEFT OUTER JOIN
      CIM_Product ON CIM_Product.product_LUID =
      PhysicalPackage_Product.groupComponent) CIM_Product
   ON CIM_Product.antecedent = portController_LUID
   WHERE PortInfo.snapshotID is NOT NULL
GO

CREATE VIEW R_StoragePorts
AS
SELECT  devices.DeviceKey, devices.Name AS DeviceName,
        CIM_NetworkPort.ElementName AS PortName,
        CIM_NetworkPort.PortNumber AS Number_,
        CIM_NetworkPort.PermanentAddress AS WorldWideName,
        CIM_NetworkPort.R_ParentName AS ControllerHBAName,
        CIM_NetworkPort.R_OperationalStatus AS Status,
        CIM_NetworkPort.PortType AS Type, CIM_NetworkPort.Speed,
        CIM_NetworkPort.MaxSpeed, CIM_NetworkPort.SnapshotID
FROM    devices RIGHT OUTER JOIN
        CIM_NetworkPort ON devices.DeviceKey = CIM_NetworkPort.NodeID
GO

CREATE VIEW R_StorageLogicalUnits
AS
SELECT  devices.DeviceKey, devices.Name AS DeviceName,
        CIM_StorageVolume.ElementName AS LUNName,
        CIM_StorageVolume.Name AS ID,
        CIM_StorageVolume.R_OperationalStatus AS Status,
        CIM_StorageVolume.R_ExtentStatus AS ExtentStatus,
        CIM_StorageVolume.BlockSize * CIM_StorageVolume.NumberOfBlocks AS LUNSize,
        CIM_StorageVolume.R_RaidLevel AS RAIDLevel,
        CIM_StoragePool.ElementName AS StoragePool, CIM_StorageVolume.SnapshotID
FROM    devices RIGHT OUTER JOIN
	CIM_ComputerSystem ON
	cim_computerSystem.nodeId = deviceKey LEFT OUTER JOIN
	ComputerSys_StorageVol ON
	computerSys_StorageVol.groupComponent = computerSystem_LUID LEFT OUTER JOIN
	CIM_StorageVolume ON
	storageVolume_LUID = computerSys_StorageVol.partComponent LEFT OUTER JOIN
	SVAllocatedFromStoragePool ON
	SVAllocatedFromStoragePool.dependent = storageVolume_LUID LEFT OUTER JOIN
	CIM_StoragePool ON
	SVAllocatedFromStoragePool.Antecedent = CIM_StoragePool.StoragePool_LUID
	where CIM_StorageVolume.snapshotID IS NOT NULL
GO

---- --------

CREATE VIEW R_StorageDeviceCapacity
AS
select  dev.DeviceKey, dev.Name AS DeviceName, csname.name AS ID, rawcapacity, unallocated,
        carved, DECODE(presented,NULL,0,presented) AS presented,
        DECODE(unpresented,NULL,0,unpresented) AS unpresented,
        (DECODE(carved,NULL,0,carved) - (DECODE(presented,NULL,0,presented) +
        DECODE(unpresented,NULL,0,unpresented)) ) AS overhead,
	rc.snapshotId
FROM
    (SELECT CS.nodeId AS id, CS.snapshotId snapshotId, SUM(TOTALMANAGEDSPACE) rawcapacity
    FROM CIM_STORAGEPOOL SP , CIM_COMPUTERSYSTEM CS ,
    CIM_HOSTEDSTORAGEPOOL CS2SP WHERE SP.PRIMORDIAL = 1 AND
    CS.COMPUTERSYSTEM_LUID = CS2SP.GROUPCOMPONENT AND
    CS2SP.PARTCOMPONENT = SP.STORAGEPOOL_LUID group by cs.nodeid, cs.snapshotId) rc
    LEFT OUTER JOIN
    (SELECT CS.nodeid AS id, cs.snapshotId, SUM(REMAININGMANAGEDSPACE) unallocated
    FROM CIM_STORAGEPOOL SP , CIM_COMPUTERSYSTEM CS ,
    CIM_HOSTEDSTORAGEPOOL CS2SP
    WHERE CS.COMPUTERSYSTEM_LUID = CS2SP.GROUPCOMPONENT AND
    CS2SP.PARTCOMPONENT = SP.STORAGEPOOL_LUID
    group by cs.nodeid, cs.snapshotId) uc
    ON (uc.id = rc.id AND uc.snapshotId = rc.snapshotId) LEFT OUTER JOIN
    (SELECT sv.nodeid AS id, sv.snapshotId, SUM(SPACECONSUMED) carved
    FROM SVALLOCATEDFROMSTORAGEPOOL AFSP , CIM_STORAGEVOLUME SV
    WHERE AFSP.DEPENDENT = SV.STORAGEVOLUME_LUID group by sv.nodeid, sv.snapshotId) cs
    ON (uc.id = cs.id AND uc.snapshotId = cs.snapshotId) LEFT OUTER JOIN
    (SELECT sv.nodeid id, sv.snapshotId, sum(blocksize*numberofblocks) presented
    FROM CIM_STORAGEVOLUME SV where storageVolume_LUID in
    (select distinct dependent from CIM_ProtocolControllerForUnit pcfu,
    cim_Storagevolume sv  where sv.storagevolume_LUID = pcfu.dependent)
    group by nodeid, snapshotid) ps
    ON (cs.id = ps.id AND cs.snapshotId = ps.snapshotId) LEFT OUTER JOIN
    (select sv.nodeid AS id, sv.snapshotId, sum(blocksize * numberofblocks)  unpresented
    from cim_storagevolume sv LEFT JOIN cim_protocolcontrollerforunit
    ON sv.storagevolume_luid  = dependent where dependent IS NULL
    group by sv.nodeid, sv.snapshotId) up
    ON ( rc.id = up.id AND rc.snapshotId = up.snapshotId) LEFT OUTER JOIN
    (select nodeId AS id, snapshotId, Name from CIM_ComputerSystem where
    computerSystem_LUID not in (select partComponent from CIM_ComponentCS )) csname
    ON (csname.id = rc.id AND csname.snapshotId = rc.snapshotId) LEFT OUTER JOIN
    (select DeviceKey, Name from devices ) dev ON rc.id = dev.DeviceKey
GO

CREATE VIEW R_Software
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_SoftwareIdentity.SnapshotID, CIM_SoftwareIdentity.Description,
                 CIM_SoftwareIdentity.dc_OtherVersionInfo AS Version, CIM_SoftwareIdentity.TargetType AS Executable,
                 CIM_SoftwareIdentity.Device_SW_PurposeDescription AS TypeValue, CIM_SoftwareIdentity.R_Status AS Status,
                 CIM_SoftwareIdentity.InstallDate AS Date_, CIM_SoftwareIdentity.R_Type AS Type
FROM    CIM_SoftwareIdentity LEFT OUTER JOIN
                 devices ON CIM_SoftwareIdentity.NodeID = devices.DeviceKey
)
GO
-----new reporting item for Quake CR3-----
DROP VIEW R_CPU
GO

CREATE VIEW R_CPU
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_Processor.Name AS CPUType,
               CIM_Processor.CurrentClockSpeed AS CPUSpeed, CIM_Processor.OtherIdentifyingInfo AS SlotNumber,
               CIM_Processor.SnapshotID, CIM_Processor.Family AS FirmwareID, CIM_Processor.LoadPercentage AS ProcessorLoad,
               CIM_Processor.R_CPUStatus AS ProcessorAllocated, CIM_Processor.dc_HWLocation AS Location,
               CIM_Processor.ProcessorLocation_CellNumber AS CellNumber, CIM_Processor.ArchitectureRevision,
               CIM_Processor.FirmwareRevision, CIM_Processor.DataWidth
FROM  CIM_Processor LEFT OUTER JOIN
               devices ON CIM_Processor.NodeID = devices.DeviceKey
)
GO

DROP VIEW R_DIMMSlots
GO

CREATE VIEW R_DIMMSlots
AS(
SELECT     devices.DeviceKey, devices.Name AS DeviceName, CIM_PhysicalMemory.FormFactor,
                      CIM_PhysicalMemory.Capacity / 1024 AS MemorySize, CIM_PhysicalMemory.PartNumber, CIM_PhysicalMemory.SerialNumber,
                      CIM_PhysicalMemory.R_Slot AS SlotNumber, CIM_PhysicalMemory.R_MemoryType AS MemoryType,
                      CIM_PhysicalMemory.R_MemoryTech AS MemoryTech, CIM_PhysicalMemory.dc_HWLocation AS Location,
                      CIM_PhysicalMemory.SnapshotID, CIM_PhysicalMemory.MemLoc_LocationIdentifiers AS LocationId,
                      CIM_PhysicalMemory.Description, CIM_PhysicalMemory.BankLabel, CIM_PhysicalMemory.Tag
FROM         CIM_PhysicalMemory LEFT OUTER JOIN
                      devices ON CIM_PhysicalMemory.NodeID = devices.DeviceKey
)
GO


DROP VIEW R_NetworkInterface
GO
CREATE VIEW R_NetworkInterface
AS(
SELECT     CIM_NetworkAdapter.NodeID AS DeviceKey, CIM_NetworkAdapter.SystemName AS DeviceName,
                      CIM_NetworkAdapter.Caption AS Description, CIM_NetworkAdapter.PermanentAddress AS MacAddress, IPAddress.IPAddress,
                      CIM_NetworkAdapter.EthernetAdp_InternalMACRcvErr AS InputErrors, CIM_NetworkAdapter.EthernetAdp_InternalMACTranErr AS OutputErrors,
                      CIM_NetworkAdapter.MaxSpeed AS Speed, CIM_NetworkAdapter.R_Duplex AS Duplex, CIM_NetworkAdapter.FullDuplex,
                      CIM_NetworkAdapter.Name AS InterfaceName, CIM_NetworkAdapter.IPProtocolEndpoint_SubnetMask AS SubnetMask,
                      CIM_NetworkAdapter.dc_BroadcastAddress AS BroadcastAddress, CIM_NetworkAdapter.StatusInfo AS InterfaceState,
                      CIM_NetworkAdapter.dc_DHCPEnabled AS DHCPEnabled, IPAddress.IPAddressNumber AS IPLongValue, CIM_NetworkAdapter.SnapshotID,
                      CIM_NetworkAdapter.LANEndpoint_OperationalStatus AS OperationalStatus, CIM_NetworkAdapter.LANEndpoint_ProtocolType AS ProtocolType,
                      CIM_NetworkAdapter.EthernetPort_MaxDataSize AS MaxDataSize, CIM_NetworkAdapter.EthernetPort_PortType AS PortType
FROM         IPAddress RIGHT OUTER JOIN
                      CIM_NetworkAdapter ON IPAddress.DeviceKey = CIM_NetworkAdapter.NodeID AND
                      IPAddress.MACaddr = CIM_NetworkAdapter.R_MacAddress
WHERE     (NOT (CIM_NetworkAdapter.Caption LIKE N'%ppp%') AND NOT (CIM_NetworkAdapter.Caption LIKE N'%Loopback%'))
)
GO

CREATE VIEW R_UnixSensors
AS(
SELECT     CIM_Sensor.NodeID AS DeviceKey, CIM_Sensor.SystemName AS DeviceName, CIM_Sensor.Name AS SensorName,
           CIM_Sensor.NodeID AS SensorId, CIM_Sensor.SensorType, CIM_Sensor.SnapshotID
FROM       CIM_Sensor LEFT OUTER JOIN
               devices ON CIM_Sensor.NodeID = devices.DeviceKey
)
GO

CREATE VIEW R_PowerSupply
AS(
SELECT devices.DeviceKey, devices.Name AS DeviceName, CIM_PowerSupply.DeviceID, CIM_PhysicalElement.Model AS ModelName,
               CIM_PhysicalElement.SerialNumber, CIM_PhysicalElement.dc_FirmwareRevision AS FirmwareRev,
               CIM_PowerSupply.Availability AS ConditionVal, CIM_PowerSupply.TotalOutputPower / 1000 AS MaxCapacity,
               CIM_PowerSupply.dc_CurrentOutputPower / 1000 AS UsedCapacity, CIM_PowerSupply.dc_RedundancyState AS RedundancyState,
               CIM_PowerSupply.dc_PowerSupplyStatus AS Status, CIM_PowerSupply.R_Condition AS Condition, CIM_PowerSupply.SnapshotID,
               CIM_PowerSupply.OtherIdentifyingInfo AS Description
FROM  devices INNER JOIN
               CIM_PhysicalElement ON devices.DeviceKey = CIM_PhysicalElement.NodeID RIGHT OUTER JOIN
               CIM_PowerSupply ON CIM_PhysicalElement.NodeID = CIM_PowerSupply.NodeID AND
               CIM_PhysicalElement.SnapshotID = CIM_PowerSupply.SnapshotID AND CIM_PhysicalElement.Tag = CIM_PowerSupply.DeviceID
)
GO
-- ----------------------------------------------------------------------------------------------------
-- Fixed bug 243547 caculate complex computer cabinet count and IO cabinet count
-- ----------------------------------------------------------------------------------------------------

CREATE VIEW R_CellularComputeCabCount
AS
SELECT     NodeID, SnapshotID, COUNT(CabinetType) AS ComputeCabCount
FROM       HP_NParCabinet
WHERE     (CabinetType IN (2, 3, 4, 5))
GROUP BY NodeID, SnapshotID
ORDER BY NodeID

GO

CREATE VIEW R_CellularIOCabCount
AS
SELECT      NodeID, SnapshotID, COUNT(CabinetType) AS IOCabCount
FROM       HP_NParCabinet
WHERE     (CabinetType IN (6))
GROUP BY NodeID, SnapshotID
ORDER BY NodeID

GO
DROP VIEW R_CellularSysParComplex
GO
CREATE VIEW R_CellularSysParComplex
AS
SELECT     devices.DeviceKey, devices.Name AS DeviceName, HP_NParComplex.ComplexName,
                      DECODE(HP_NParComplex.dc_ComputeCabCount,NULL, DECODE(R_CellularComputeCabCount.ComputeCabCount,null, 0)) AS ComputeCabinets,
                      DECODE(HP_NParComplex.dc_IOXCabCount,null, DECODE(R_CellularIOCabCount.IOCabCount,null, 0)) AS IOCabinets,
                      HP_NParComplex.SnapshotID
FROM         HP_NParComplex INNER JOIN
                      devices ON HP_NParComplex.NodeID = devices.DeviceKey LEFT OUTER JOIN
                      R_CellularIOCabCount ON HP_NParComplex.NodeID = R_CellularIOCabCount.NodeID AND
                      HP_NParComplex.SnapshotID = R_CellularIOCabCount.SnapshotID LEFT OUTER JOIN
                      R_CellularComputeCabCount ON HP_NParComplex.NodeID = R_CellularComputeCabCount.NodeID AND
                      HP_NParComplex.SnapshotID = R_CellularComputeCabCount.SnapshotID
GO
DROP VIEW R_CellularSysPartition
GO
CREATE VIEW R_CellularSysPartition
AS
SELECT     devices.DeviceKey, devices.Name AS DeviceName, HP_NParPartition.PartitionName, IPAddress.IPAddress,
                      HP_NParPartition.dc_TotalCPU AS TotalCPUCore, HP_NParPartition.dc_InstalledCells AS InstalledCells,
                      HP_NParPartition.dc_PoweredOnCells AS PoweredonCells, HP_NParPartition.dc_CoreCell AS CoreCell,
                      HP_NParPartition.dc_CoreCellCabinet AS CoreCellCabinet, HP_NParPartition.r_dc_HasInterleaveMem AS HasInterleaveMemory,
                      HP_NParPartition.SnapshotID
FROM         devices INNER JOIN
                      HP_NParPartition ON devices.DeviceKey = HP_NParPartition.NodeID LEFT OUTER JOIN
                      IPAddress ON devices.DeviceKey = IPAddress.DeviceKey

GO

CREATE VIEW R_Inventory
AS
SELECT devices.DeviceKey, devices.Name AS DeviceName, devices.ProductName, DB_DeviceInfoEx.ProductId, 
               DB_DeviceInfoEx.TotalMemory AS MemorySize, DB_DeviceInfoEx.ROMVersion, DB_DeviceInfoEx.SerialNumber, 
               DB_DeviceInfoEx.AssetTag, DB_DeviceInfoEx.OSName, IPAddress.IPAddress, IPAddress.IPAddressNumber AS IPLongValue, 
               DB_DeviceInfoEx.OSVendor, computerSystem.SnapshotID, computerSystem.PrimaryOwnerContact AS DeviceOwner, 
               computerSystem.dc_SystemLocation AS Location, devices.ProductType, devices.OverallStatus AS DeviceStatus, 
               CIM_OperatingSystem.LastBootUpTime AS DeviceBootTime, devices.ProductSubType, devices.ProductTypeStr, 
               DC_ProliantHost.ServerRole, IPXAddress.IPXAddress
FROM  devices LEFT OUTER JOIN
               IPXAddress ON devices.DeviceKey = IPXAddress.DeviceKey AND IPXAddress.ipxIndex = 0 LEFT OUTER JOIN
               DB_DeviceInfoEx ON devices.DeviceKey = DB_DeviceInfoEx.DeviceKey LEFT OUTER JOIN
               DC_ProliantHost RIGHT OUTER JOIN CIM_OperatingSystem RIGHT OUTER JOIN
               (SELECT CIM_ComputerSystem.SnapshotID, CIM_ComputerSystem.PrimaryOwnerContact, 
               CIM_ComputerSystem.dc_SystemLocation, CIM_ComputerSystem.NodeID
               FROM   CIM_ComputerSystem 
               WHERE (CIM_ComputerSystem.ComputerSystem_LUID NOT IN
               (SELECT partComponent
               FROM   CIM_ComponentCS ))) computerSystem ON CIM_OperatingSystem.NodeID = computerSystem.NodeID AND 
               CIM_OperatingSystem.SnapshotID = computerSystem.SnapshotID ON DC_ProliantHost.SnapshotID = computerSystem.SnapshotID AND 
               DC_ProliantHost.NodeID = computerSystem.NodeID ON devices.DeviceKey = computerSystem.NodeID LEFT OUTER JOIN
               IPAddress ON devices.DeviceKey = IPAddress.DeviceKey AND IPAddress.ipindex = 0
GO
